#!/usr/bin/env python

###
# Copyright (c) 2002-2007 Systems in Motion
#
# Permission to use, copy, modify, and distribute this software for any
# purpose with or without fee is hereby granted, provided that the above
# copyright notice and this permission notice appear in all copies.
#
# THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
# WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
# MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
# ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
# WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
# ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
# OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
#

###
# This is an example from the Inventor Mentor,
# chapter 5, example 6.
#
# This example shows the effect of different order of
# operation of transforms.  The left object is first
# scaled, then rotated, and finally translated to the left.  
# The right object is first rotated, then scaled, and finally
# translated to the right.
#

import sys

from pivy.coin import *
from pivy.sogui import *

def main():
    # Initialize Inventor and Qt
    myWindow = SoGui.init(sys.argv[0])
    if myWindow == None: sys.exit(1)

    root = SoSeparator()

    # Create two separators, for left and right objects.
    leftSep = SoSeparator()
    rightSep = SoSeparator()
    root.addChild(leftSep)
    root.addChild(rightSep)

    # Create the transformation nodes
    leftTranslation  = SoTranslation()
    rightTranslation = SoTranslation()
    myRotation = SoRotationXYZ()
    myScale = SoScale()

    # Fill in the values
    leftTranslation.translation = (-1.0, 0.0, 0.0)
    rightTranslation.translation = (1.0, 0.0, 0.0)
    myRotation.angle = M_PI/2   # 90 degrees
    myRotation.axis = SoRotationXYZ.X
    myScale.scaleFactor = (2., 1., 3.)

    # Add transforms to the scene.
    leftSep.addChild(leftTranslation)   # left graph
    leftSep.addChild(myRotation)        # then rotated
    leftSep.addChild(myScale)           # first scaled

    rightSep.addChild(rightTranslation) # right graph
    rightSep.addChild(myScale)          # then scaled
    rightSep.addChild(myRotation)       # first rotated

    # Read an object from file. (as in example 4.2.Lights)
    myInput = SoInput()
    if not myInput.openFile("temple.iv"):
        sys.exit(1)

    fileContents = SoDB.readAll(myInput)
    if fileContents == None: 
        sys.exit(1)

    # Add an instance of the object under each separator.
    leftSep.addChild(fileContents)
    rightSep.addChild(fileContents)

    # Construct a renderArea and display the scene.
    myViewer = SoGuiExaminerViewer(myWindow)
    myViewer.setSceneGraph(root)
    myViewer.setTitle("Transform Ordering")
    myViewer.show()
    myViewer.viewAll()

    SoGui.show(myWindow)
    SoGui.mainLoop()

if __name__ == "__main__":
    main()



import os, sys
import subprocess
from distutils.spawn import find_executable

class QtInfo(object):
    def __init__(self, qmake_command=None):
        if qmake_command:
            self._qmake_command = qmake_command
        else:
            self._qmake_command = [find_executable("qmake"),]
        self._dict = {}
        # bind all variables early at __init__ time.
        for thing in self.__class__.__dict__:
            getattr(self, thing)

    def getQMakeCommand(self):
        qmake_command_string = self._qmake_command[0]
        for entry in self._qmake_command[1:]:
            qmake_command_string += " %s" %(entry)
        return qmake_command_string

    def getVersion(self):
        return self.getProperty("QT_VERSION")

    def getBinsPath(self):
        return self.getProperty("QT_INSTALL_BINS")

    def getLibsPath(self):
        return self.getProperty("QT_INSTALL_LIBS")

    def getLibsExecsPath(self):
        return self.getProperty("QT_INSTALL_LIBEXECS")

    def getPluginsPath(self):
        return self.getProperty("QT_INSTALL_PLUGINS")

    def getPrefixPath(self):
        return self.getProperty("QT_INSTALL_PREFIX")

    def getImportsPath(self):
        return self.getProperty("QT_INSTALL_IMPORTS")

    def getTranslationsPath(self):
        return self.getProperty("QT_INSTALL_TRANSLATIONS")

    def getHeadersPath(self):
        return self.getProperty("QT_INSTALL_HEADERS")

    def getDocsPath(self):
        return self.getProperty("QT_INSTALL_DOCS")

    def getQmlPath(self):
        return self.getProperty("QT_INSTALL_QML")

    def _getProperty(self, prop_name):
        cmd = self._qmake_command + ["-query", prop_name]
        proc = subprocess.Popen(cmd, stdout = subprocess.PIPE, shell=False)
        prop = proc.communicate()[0]
        proc.wait()
        if proc.returncode != 0:
            return None
        if sys.version_info >= (3,):
            return str(prop, 'ascii').strip()
        return prop.strip()

    def getProperty(self, prop_name):
        if prop_name not in self._dict:
            self._dict[prop_name] = self._getProperty(prop_name)
        return self._dict[prop_name]

    version = property(getVersion)
    bins_dir = property(getBinsPath)
    libs_dir = property(getLibsPath)
    lib_execs_dir = property(getLibsExecsPath)
    plugins_dir = property(getPluginsPath)
    prefix_dir = property(getPrefixPath)
    qmake_command = property(getQMakeCommand)
    imports_dir = property(getImportsPath)
    translations_dir = property(getTranslationsPath)
    headers_dir = property(getHeadersPath)
    docs_dir = property(getDocsPath)
    qml_dir = property(getQmlPath)


#!/usr/bin/env python

###
# Copyright (c) 2002-2007 Systems in Motion
#
# Permission to use, copy, modify, and distribute this software for any
# purpose with or without fee is hereby granted, provided that the above
# copyright notice and this permission notice appear in all copies.
#
# THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
# WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
# MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
# ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
# WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
# ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
# OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
#

###
# This is an example from the Inventor Mentor,
# chapter 2, example 1.
#
# Hello Cone example program; draws a red cone in a window.
#

import sys

from pivy.sogui import *
from pivy.coin import *

def main():
    # Initialize Inventor. This returns a main window to use.
    # If unsuccessful, exit.

    myWindow = SoGui.init(sys.argv[0])
    if myWindow == None: sys.exit(1)

    # Make a scene containing a red cone
    root = SoSeparator()

    bitmap_x = ("xxxx             xxxx" +
                "xxxxx           xxxxx" +
                "xxxxxx         xxxxxx" +
                "xxxxxxx       xxxxxxx" +
                " xxxxxxx     xxxxxxx " +
                "  xxxxxxx   xxxxxxx  " +
                "   xxxxxxx xxxxxxx   " +
                "    xxxxxxxxxxxxx    " +
                "     xxxxxxxxxxx     " +
                "      xxxxxxxxx      " +
                "       xxxxxxx       " +
                "      xxxxxxxxx      " +
                "     xxxxxxxxxxx     " +
                "    xxxxxxxxxxxxx    " +
                "   xxxxxxx xxxxxxx   " +
                "  xxxxxxx   xxxxxxx  " +
                " xxxxxxx     xxxxxxx " +
                "xxxxxxx       xxxxxxx" +
                "xxxxxx         xxxxxx" +
                "xxxxx           xxxxx" +
                "xxxx             xxxx")

    SoMarkerSet.CUSTOM_BIT_MAP_1 = SoMarkerSet.getNumDefinedMarkers()
    SoMarkerSet.addMarker(SoMarkerSet.CUSTOM_BIT_MAP_1, SbVec2s([21,21]), bitmap_x,
                          False, False)

    bitmap_dot = ("    xxxxxx    " +
                  "  xxxxxxxxxx  " +
                  " xxxxxxxxxxxx " +
                  " xxxxxxxxxxxx " +
                  "xxxxxxxxxxxxxx" +
                  "xxxxxxxxxxxxxx" +
                  "xxxxxxxxxxxxxx" +
                  "xxxxxxxxxxxxxx" +
                  "xxxxxxxxxxxxxx" +
                  "xxxxxxxxxxxxxx" +
                  " xxxxxxxxxxxx " +
                  " xxxxxxxxxxxx " +
                  "  xxxxxxxxxx  " +
                  "    xxxxxx    ")
    
    SoMarkerSet.CUSTOM_BIT_MAP_2 = SoMarkerSet.getNumDefinedMarkers()
    SoMarkerSet.addMarker(SoMarkerSet.CUSTOM_BIT_MAP_2, SbVec2s([14, 14]), bitmap_dot,
                          False, False)

    color = SoMaterial()
    color.diffuseColor = (1., 0., 0.)

    marker1 = SoMarkerSet()
    marker1.markerIndex = SoMarkerSet.CUSTOM_BIT_MAP_1
    data1 = SoCoordinate3()
    data1.point.setValue(0, 0, 0)
    data1.point.setValues(0, 1, [[0., 0., 0.]])

    marker2 = SoMarkerSet()
    marker2.markerIndex = SoMarkerSet.CUSTOM_BIT_MAP_2
    data2 = SoCoordinate3()
    data2.point.setValue(0, 0, 0)
    data2.point.setValues(0, 1, [[1., 0., 0.]])

    myCamera = SoPerspectiveCamera()
    root.addChild(myCamera)
    root.addChild(SoDirectionalLight())
    root.addChild(color)
    root.addChild(data1)
    root.addChild(marker1)
    root.addChild(data2)
    root.addChild(marker2)

    myRenderArea = SoGuiRenderArea(myWindow)

    myCamera.viewAll(root, myRenderArea.getViewportRegion())

    myRenderArea.setSceneGraph(root)
    myRenderArea.setTitle("Hello Cone")
    myRenderArea.show()

    SoGui.show(myWindow)
    SoGui.mainLoop()

if __name__ == "__main__":
    main()


#
# Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009 The SCons Foundation
#
# Permission is hereby granted, free of charge, to any person obtaining
# a copy of this software and associated documentation files (the
# "Software"), to deal in the Software without restriction, including
# without limitation the rights to use, copy, modify, merge, publish,
# distribute, sublicense, and/or sell copies of the Software, and to
# permit persons to whom the Software is furnished to do so, subject to
# the following conditions:
#
# The above copyright notice and this permission notice shall be included
# in all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY
# KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
# WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
# NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
# LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
# OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
# WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
#

__revision__ = "src/engine/SCons/Tool/MSCommon/vc.py 4369 2009/09/19 15:58:29 scons"

__doc__ = """Module for Visual C/C++ detection and configuration.
"""

import os

import SCons.Warnings

import common

debug = common.debug

class VisualC:
    """
    An base class for finding installed versions of Visual C/C++.
    """
    def __init__(self, version, **kw):
        self.version = version
        self.__dict__.update(kw)
        self._cache = {}

    def vcbin_arch(self):
        if common.is_win64():
            result = {
                'x86_64' : ['amd64', r'BIN\x86_amd64'],
                'ia64'   : [r'BIN\ia64'],
            }.get(target_arch, [])
        else:
            result = {
                'x86_64' : ['x86_amd64'],
                'ia64'   : ['x86_ia64'],
            }.get(target_arch, [])
        # TODO(1.5)
        #return ';'.join(result)
        return string.join(result, ';')

    # Support for searching for an appropriate .bat file.
    # The map is indexed by (target_architecture, host_architecture).
    # Entries where the host_architecture is None specify the
    # cross-platform "default" .bat file if there isn't sn entry
    # specific to the current host architecture.

    batch_file_map = {
        ('x86_64', 'x86_64') : [
            r'bin\amd64\vcvarsamd64.bat',
            r'bin\x86_amd64\vcvarsx86_amd64.bat',
        ],
        ('x86_64', 'x86') : [
            r'bin\x86_amd64\vcvarsx86_amd64.bat',
        ],
        ('ia64', 'ia64') : [
            r'bin\ia64\vcvarsia64.bat',
            r'bin\x86_ia64\vcvarsx86_ia64.bat',
        ],
        ('ia64', None) : [
            r'bin\x86_ia64\vcvarsx86_ia64.bat',
        ],
        ('x86', None) : [
            r'bin\vcvars32.bat',
        ],
    }

    def find_batch_file(self, target_architecture, host_architecture):
        key = (target_architecture, host_architecture)
        potential_batch_files = self.batch_file_map.get(key)
        if not potential_batch_files:
            key = (target_architecture, None)
            potential_batch_files = self.batch_file_map.get(key)
        if potential_batch_files:
            product_dir = self.get_vc_dir()
            for batch_file in potential_batch_files:
                bf = os.path.join(product_dir, batch_file)
                if os.path.isfile(bf):
                    return bf
        return None

    def find_vc_dir(self):
        root = 'Software\\'
        if common.is_win64():
            root = root + 'Wow6432Node\\'
        for key in self.hkeys:
            key = root + key
            try:
                comps = common.read_reg(key)
            except WindowsError as e:
                debug('find_vc_dir(): no VC registry key %s' % repr(key))
            else:
                debug('find_vc_dir(): found VC in registry: %s' % comps)
                if os.path.exists(comps):
                    return comps
                else:
                    debug('find_vc_dir(): reg says dir is %s, but it does not exist. (ignoring)'\
                              % comps)
                    return None
        return None

    #

    def get_batch_file(self, target_architecture, host_architecture):
        try:
            return self._cache['batch_file']
        except KeyError:
            batch_file = self.find_batch_file(target_architecture, host_architecture)
            self._cache['batch_file'] = batch_file
            return batch_file

    def get_vc_dir(self):
        try:
            return self._cache['vc_dir']
        except KeyError:
            vc_dir = self.find_vc_dir()
            self._cache['vc_dir'] = vc_dir
            return vc_dir
        
    def reset(self):
        self._cache={}
        

# The list of supported Visual C/C++ versions we know how to detect.
#
# The first VC found in the list is the one used by default if there
# are multiple VC installed.  Barring good reasons to the contrary,
# this means we should list VC with from most recent to oldest.
#
# If you update this list, update the documentation in Tool/vc.xml.
SupportedVCList = [
    VisualC('9.0',
            hkeys=[
                r'Microsoft\VisualStudio\9.0\Setup\VC\ProductDir',
                r'Microsoft\VCExpress\9.0\Setup\VC\ProductDir',
            ],
            default_install=r'Microsoft Visual Studio 9.0\VC',
            common_tools_var='VS90COMNTOOLS',
            vc_subdir=r'\VC',
            batch_file_base='vcvars',
            supported_arch=['x86', 'x86_64', 'ia64'],
            atlmc_include_subdir = [r'ATLMFC\INCLUDE'],
            atlmfc_lib_subdir = {
                'x86'       : r'ATLMFC\LIB',
                'x86_64'    : r'ATLMFC\LIB\amd64',
                'ia64'      : r'ATLMFC\LIB\ia64',
            },
            crt_lib_subdir = {
                'x86_64'    : r'LIB\amd64',
                'ia64'      : r'LIB\ia64',
            },
    ),
    VisualC('8.0',
            hkeys=[
                r'Microsoft\VisualStudio\8.0\Setup\VC\ProductDir',
                r'Microsoft\VCExpress\8.0\Setup\VC\ProductDir',
            ],
            default_install=r'%s\Microsoft Visual Studio 8\VC',
            common_tools_var='VS80COMNTOOLS',
            vc_subdir=r'\VC',
            batch_file_base='vcvars',
            supported_arch=['x86', 'x86_64', 'ia64'],
            atlmc_include_subdir = [r'ATLMFC\INCLUDE'],
            atlmfc_lib_subdir = {
                'x86'       : r'ATLMFC\LIB',
                'x86_64'    : r'ATLMFC\LIB\amd64',
                'ia64'      : r'ATLMFC\LIB\ia64',
            },
            crt_lib_subdir = {
                'x86_64'    : r'LIB\amd64',
                'ia64'      : r'LIB\ia64',
            },
    ),
    VisualC('7.1',
            hkeys=[
                r'Microsoft\VisualStudio\7.1\Setup\VC\ProductDir',
            ],
            default_install=r'%s\Microsoft Visual Studio 7.1.NET 2003\VC7',
            common_tools_var='VS71COMNTOOLS',
            vc_subdir=r'\VC7',
            batch_file_base='vcvars',
            supported_arch=['x86'],
            atlmc_include_subdir = [r'ATLMFC\INCLUDE'],
            atlmfc_lib_subdir = {
                'x86' : r'ATLMFC\LIB',
            },
    ),
    VisualC('7.0',
            hkeys=[
                r'Microsoft\VisualStudio\7.0\Setup\VC\ProductDir',
            ],
            default_install=r'%s\Microsoft Visual Studio .NET\VC7',
            common_tools_var='VS70COMNTOOLS',
            vc_subdir=r'\VC7',
            batch_file_base='vcvars',
            supported_arch=['x86'],
            atlmc_include_subdir = [r'ATLMFC\INCLUDE'],
            atlmfc_lib_subdir = {
                'x86' : r'ATLMFC\LIB',
            },
    ),
    VisualC('6.0',
            hkeys=[
                r'Microsoft\VisualStudio\6.0\Setup\Microsoft Visual C++\ProductDir',
            ],
            default_install=r'%s\Microsoft Visual Studio\VC98',
            common_tools_var='VS60COMNTOOLS',
            vc_subdir=r'\VC98',
            batch_file_base='vcvars',
            supported_arch=['x86'],
            atlmc_include_subdir = [r'ATL\INCLUDE', r'MFC\INCLUDE'],
            atlmfc_lib_subdir = {
                'x86' : r'MFC\LIB',
            },
    ),
]

SupportedVCMap = {}
for vc in SupportedVCList:
    SupportedVCMap[vc.version] = vc


# Finding installed versions of Visual C/C++ isn't cheap, because it goes
# not only to the registry but also to the disk to sanity-check that there
# is, in fact, something installed there and that the registry entry isn't
# just stale.  Find this information once, when requested, and cache it.

InstalledVCList = None
InstalledVCMap  = None

def get_installed_vcs():
    global InstalledVCList
    global InstalledVCMap
    if InstalledVCList is None:
        InstalledVCList = []
        InstalledVCMap = {}
        for vc in SupportedVCList:
            debug('trying to find VC %s' % vc.version)
            if vc.get_vc_dir():
                debug('found VC %s' % vc.version)
                InstalledVCList.append(vc)
                InstalledVCMap[vc.version] = vc
    return InstalledVCList


def set_vc_by_version(env, msvc):
    if msvc not in SupportedVCMap:
        msg = "VC version %s is not supported" % repr(msvc)
        raise SCons.Errors.UserError(msg)
    get_installed_vcs()
    vc = InstalledVCMap.get(msvc)
    if not vc:
        msg = "VC version %s is not installed" % repr(msvc)
        raise SCons.Errors.UserError(msg)
    set_vc_by_directory(env, vc.get_vc_dir())

# New stuff

def script_env(script):
    stdout = common.get_output(script)
    return common.parse_output(stdout)

def msvc_setup_env(env):
    debug('msvc_setup_env()')
    installed_vcs = get_installed_vcs()
    debug('InstalledVCMap:%s'%InstalledVCMap)
    msvc_version = env.get('MSVC_VERSION')
    if not msvc_version:
        if not installed_vcs:
            msg = 'No installed VCs'
            debug('msv %s\n' % repr(msg))
            SCons.Warnings.warn(SCons.Warnings.VisualCMissingWarning, msg)
            return
        msvc = installed_vcs[0]
        msvc_version = msvc.version
        env['MSVC_VERSION'] = msvc_version
        debug('msvc_setup_env: using default installed MSVC version %s\n' % repr(msvc_version))
    else:
        msvc = InstalledVCMap.get(msvc_version)
        debug('msvc_setup_env: using specified MSVC version %s\n' % repr(msvc_version))
        if not msvc:
            msg = 'VC version %s not installed' % msvc_version
            debug('msv %s\n' % repr(msg))
            SCons.Warnings.warn(SCons.Warnings.VisualCMissingWarning, msg)
            return

    host_platform = env.get('HOST_ARCH')
    if not host_platform:
      #host_platform = get_default_host_platform()
      host_platform = 'x86'
    target_platform = env.get('TARGET_ARCH')
    if not target_platform:
      target_platform = host_platform

    use_script = env.get('MSVC_USE_SCRIPT', True)
    if SCons.Util.is_String(use_script):
        debug('use_script 1 %s\n' % repr(use_script))
        d = script_env(use_script)
    elif use_script:
        script = msvc.get_batch_file(target_platform, host_platform)
        debug('use_script 2 %s target_platform:%s host_platform:%s\n' % (repr(script),target_platform,host_platform))
        d = script_env(script)
    else:
        debug('msvc.get_default_env()\n')
        d = msvc.get_default_env()

    for k, v in d.items():
        env.PrependENVPath(k, v, delete_existing=True)
      
def msvc_exists(version=None):
    vcs = get_installed_vcs()
    if version is None:
        return len(vcs) > 0
    return version in InstalledVCMap
    
    
def reset_installed_vcs():
    global InstalledVCList
    global InstalledVCMap
    InstalledVCList = None
    InstalledVCMap  = None
    for vc in SupportedVCList:
        vc.reset()

# Local Variables:
# tab-width:4
# indent-tabs-mode:nil
# End:
# vim: set expandtab tabstop=4 shiftwidth=4:



#!/usr/bin/env python
###
# Copyright (c) 2002-2007 Systems in Motion
#
# Permission to use, copy, modify, and distribute this software for any
# purpose with or without fee is hereby granted, provided that the above
# copyright notice and this permission notice appear in all copies.
#
# THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
# WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
# MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
# ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
# WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
# ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
# OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
#

"""
This is an example from the Inventor Mentor,
chapter 6, example 3.

This example renders arguments as text within an
ExaminerViewer.  It is a little fancier than 6.2.
"""

import sys

from pivy.gui.qt import *
from pivy.coin import *
from pivy.quarter import *

def main():
    # Initialize Inventor and Qt
    app = QApplication(sys.argv)
    viewer = QuarterWidget()

    root = SoGroup()

    # Set up camera
    myCamera = SoPerspectiveCamera()
    myCamera.position = (0, -(len(sys.argv) - 1) / 2, 10)
    myCamera.nearDistance = 5.0
    myCamera.farDistance = 15.0
    root += myCamera

    # Let's make the front of the text white,
    # and the sides and back shiny yellow
    myMaterial = SoMaterial()
    # diffuse
    colors = [SbColor()] * 3
    colors[0] = SbColor(1, 1, 1)
    colors[1] = SbColor(1, 1, 0)
    colors[2] = SbColor(1, 1, 0)
    myMaterial.diffuseColor.setValues(0, 3, colors)

    # specular
    colors[0].setValue(1, 1, 1)
    """
    # Note: Inventor 2.1 doesn't support multiple specular colors.
    # colors[1].setValue(1, 1, 0)
    # colors[2].setValue(1, 1, 0)
    # myMaterial.specularColor.setValues(0, 3, colors)
    """
    myMaterial.specularColor.setValue(colors[0])
    myMaterial.shininess.setValue(.1)
    root += myMaterial

    # Choose a font likely to exist.
    myFont = SoFont()
    # times new roman somehow changes the normals of the text and so the beveling
    # is done in the wrong directions. Commenting out this line solves this issue here

    # myFont.name = "times" # "Times-Roman"
    root += myFont

    # Specify a beveled cross-section for the text
    myProfileCoords = SoProfileCoordinate2()
    coords = [SbVec2f()] * 4
    coords[0] = SbVec2f(.00, .00)
    coords[1] = SbVec2f(.25, .25)
    coords[2] = SbVec2f(1.25, .25)
    coords[3] = SbVec2f(1.50, .00)
    myProfileCoords.point.setValues(0, 4, coords)
    root += myProfileCoords

    myLinearProfile = SoLinearProfile()
    index = (0, 1, 2, 3)
    myLinearProfile.index.setValues(0, 4, index)
    root += myLinearProfile

    # Set the material binding to PER_PART
    myMaterialBinding = SoMaterialBinding()
    myMaterialBinding.value = SoMaterialBinding.PER_PART
    root += myMaterialBinding

    # Add the text
    myText3 = SoText3()
    myText3.string = "Beveled Text"
    myText3.justification = SoText3.CENTER
    myText3.parts = SoText3.ALL

    root += myText3
	
    viewer.setSceneGraph(root)
    viewer.setWindowTitle("Complex 3D Text")
    viewer.show()
    viewer.viewAll()

    sys.exit(app.exec_())

if __name__ == "__main__":
    main()


#!/usr/bin/env python

###
# Copyright (c) 2002-2007 Systems in Motion
#
# Permission to use, copy, modify, and distribute this software for any
# purpose with or without fee is hereby granted, provided that the above
# copyright notice and this permission notice appear in all copies.
#
# THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
# WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
# MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
# ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
# WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
# ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
# OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
#

###
# This is an example from the Inventor Mentor
# chapter 13, example 5.
#
# Gate engine.
# Mouse button presses enable and disable a gate engine.
# The gate engine controls an elapsed time engine that
# controls the motion of the duck.
#

from __future__ import print_function
import sys

from pivy.coin import *
from pivy.sogui import *

#############################################################
# CODE FOR The Inventor Mentor STARTS HERE  (part 2)

# This routine is called for every mouse button event.
def myMousePressCB(userData, eventCB):
    # In Pivy no cast is necessary as it gets autocasted for you.
    gate = userData
    event = eventCB.getEvent()

    # Check for mouse button being pressed
    if SoMouseButtonEvent.isButtonPressEvent(event, SoMouseButtonEvent.ANY):

        # Toggle the gate that controls the duck motion
        if gate.enable.getValue():
            gate.enable = FALSE
        else:
            gate.enable = TRUE

        eventCB.setHandled()

# CODE FOR The Inventor Mentor ENDS HERE
#############################################################


def main():
    # Print out usage message
    print("Click the left mouse button to enable/disable the duck motion")

    # Initialize Inventor and Qt
    myWindow = SoGui.init(sys.argv[0])  
    if myWindow == None: sys.exit(1)     

    root = SoSeparator()

    # Add a camera and light
    myCamera = SoPerspectiveCamera()
    myCamera.position = (0., -4., 8.0)
    myCamera.heightAngle = M_PI/2.5
    myCamera.nearDistance = 1.0
    myCamera.farDistance = 15.0
    root.addChild(myCamera)
    root.addChild(SoDirectionalLight())

    # Rotate scene slightly to get better view
    globalRotXYZ = SoRotationXYZ()
    globalRotXYZ.axis = SoRotationXYZ.X
    globalRotXYZ.angle = M_PI/9
    root.addChild(globalRotXYZ)

    # Pond group
    pond = SoSeparator()
    root.addChild(pond)
    cylMaterial = SoMaterial()
    cylMaterial.diffuseColor = (0., 0.3, 0.8)
    pond.addChild(cylMaterial)
    cylTranslation = SoTranslation()
    cylTranslation.translation = (0., -6.725, 0.)
    pond.addChild(cylTranslation)
    myCylinder = SoCylinder()
    myCylinder.radius = 4.0
    myCylinder.height = 0.5
    pond.addChild(myCylinder)

#############################################################
# CODE FOR The Inventor Mentor STARTS HERE  (part 1)

    # Duck group
    duck = SoSeparator()
    root.addChild(duck)

    # Read the duck object from a file and add to the group
    myInput = SoInput()
    if not myInput.openFile("duck.iv"):
        sys.exit(1)
    duckObject = SoDB.readAll(myInput)
    if duckObject == None:
        sys.exit(1)

    # Set up the duck transformations
    duckRotXYZ = SoRotationXYZ()
    duck.addChild(duckRotXYZ)
    initialTransform = SoTransform()
    initialTransform.translation = (0., 0., 3.)
    initialTransform.scaleFactor = (6., 6., 6.)
    duck.addChild(initialTransform)

    duck.addChild(duckObject)

    # Update the rotation value if the gate is enabled.
    myGate = SoGate(SoMFFloat.getClassTypeId())
    myCounter = SoElapsedTime()
    myGate.input.connectFrom(myCounter.timeOut) 
    duckRotXYZ.axis = SoRotationXYZ.Y  # rotate about Y axis
    duckRotXYZ.angle.connectFrom(myGate.output)

    # Add an event callback to catch mouse button presses.
    # Each button press will enable or disable the duck motion.
    myEventCB = SoEventCallback()
    myEventCB.addEventCallback(SoMouseButtonEvent.getClassTypeId(),
                               myMousePressCB, myGate)
    root.addChild(myEventCB)

# CODE FOR The Inventor Mentor ENDS HERE
#############################################################

    myRenderArea = SoGuiRenderArea(myWindow)
    myRenderArea.setSceneGraph(root)
    myRenderArea.setTitle("Duck Pond")
    myRenderArea.show()

    SoGui.show(myWindow)
    SoGui.mainLoop()

if __name__ == "__main__":
    main()



#!/usr/bin/env python

###
# Copyright (c) 2002-2007 Systems in Motion
#
# Permission to use, copy, modify, and distribute this software for any
# purpose with or without fee is hereby granted, provided that the above
# copyright notice and this permission notice appear in all copies.
#
# THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
# WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
# MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
# ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
# WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
# ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
# OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
#

###
# This is an example from the Inventor Mentor,
# volume 1, chapter 15, example 3.
#
# Manipulator attachment example.
#
# The scene graph has an SoWrapperKit, a cube and a sphere.
# A file containing a luxo lamp is read in as the 'contents'
# part of the SoWrapperKit.
# When the user picks on the SoWrapperKit (lamp), the kit's 
# "transform" part is replaced with an SoTransformBoxManip.
# Alternatively, when the user picks the sphere, the
# sphere's associated transform is replaced by an
# SoHandleBoxManip.  Picking the cube causes an 
# SoTrackballManip to replace the cube's transform.
# 
# Manipulator callbacks are used to change
# the color of the object being manipulated.
# 
# Note that for illustration purposes, the
# cube and SoWrapperKit already have transform nodes 
# associated with them; the sphere does not. In all cases, 
# the routine createTransformPath() is used to find the 
# transform node that affects the picked object.
#

import sys

from pivy.coin import *
from pivy.sogui import *

# global data
myHandleBox      = None
myTrackball      = None
myTransformBox   = None
handleBoxPath    = None
trackballPath    = None
transformBoxPath = None

# Is this node of a type that is influenced by transforms?
def isTransformable(myNode):
    if (myNode.isOfType(SoGroup.getClassTypeId()) or
        myNode.isOfType(SoShape.getClassTypeId()) or
        myNode.isOfType(SoCamera.getClassTypeId()) or
        myNode.isOfType(SoLight.getClassTypeId())):
        return TRUE
    else: 
        return FALSE

#  Create a path to the transform node that affects the tail
#  of the input path.  Three possible cases:
#   [1] The path-tail is a node kit. Just ask the node kit for
#       a path to the part called "transform"
#   [2] The path-tail is NOT a group.  Search siblings of path
#       tail from right to left until you find a transform. If
#       none is found, or if another transformable object is 
#       found (shape,group,light,or camera), then insert a 
#       transform just to the left of the tail. This way, the 
#       manipulator only effects the selected object.
#   [3] The path-tail IS a group.  Search its children left to
#       right until a transform is found. If a transformable
#       node is found first, insert a transform just left of 
#       that node.  This way the manip will affect all nodes
#       in the group.
def createTransformPath(inputPath):
    pathLength = inputPath.getLength()
    if pathLength < 2: # Won't be able to get parent of tail
        return None

    tail = inputPath.getTail()

    # CASE 1: The tail is a node kit.
    # Nodekits have built in policy for creating parts.
    # The kit copies inputPath, then extends it past the 
    # kit all the way down to the transform. It creates the
    # transform if necessary.
    if tail.isOfType(SoBaseKit.getClassTypeId()):
        kit = tail
        return kit.createPathToPart("transform", TRUE, inputPath)

    editXf = None
    parent = None
    existedBefore = FALSE

    # CASE 2: The tail is not a group.
    isTailGroup = tail.isOfType(SoGroup.getClassTypeId())
    if not isTailGroup:
        # 'parent' is node above tail. Search under parent right
        # to left for a transform. If we find a 'movable' node
        # insert a transform just left of tail.  
        parent = inputPath.getNode(pathLength - 2)
        tailIndx = parent.findChild(tail)

        for i in range(tailIndx, -1, -1):
            if editXf != None:
                break
            myNode = parent.getChild(i)
            if myNode.isOfType(SoTransform.getClassTypeId()):
                editXf = myNode
            elif i != tailIndx and isTransformable(myNode):
                break

        if editXf == None:
            existedBefore = FALSE
            editXf = SoTransform()
            parent.insertChild(editXf, tailIndx)
        else:
            existedBefore = TRUE

    # CASE 3: The tail is a group.
    else:
        # Search the children from left to right for transform 
        # nodes. Stop the search if we come to a movable node.
        # and insert a transform before it.
        parent = tail
        for i in range(parent.getNumChildren()):
            if editXf != None:
                break
            myNode = parent.getChild(i)
            if myNode.isOfType(SoTransform.getClassTypeId()):
                editXf = myNode
            elif isTransformable(myNode):
                break

        if editXf == None:
            existedBefore = FALSE
            editXf = SoTransform()
            parent.insertChild(editXf, i)
        else:
            existedBefore = TRUE

    # Create 'pathToXform.' Copy inputPath, then make last
    # node be editXf.
    pathToXform = None
    pathToXform = inputPath.copy()
    if not isTailGroup: # pop off the last entry.
        pathToXform.pop()
    # add editXf to the end
    xfIndex = parent.findChild(editXf)
    pathToXform.append(xfIndex)
    
    return pathToXform

# This routine is called when an object
# gets selected. We determine which object
# was selected, then call replaceNode()
# to replace the object's transform with
# a manipulator.
def selectionCallback(void, # user data is not used
                      selectionPath):
    global myHandleBox, myTrackball, myTransformBox, handleBoxPath
    global trackballPath, transformBoxPath

    # Attach the manipulator.
    # Use the convenience routine to get a path to
    # the transform that effects the selected object.
    xformPath = createTransformPath(selectionPath)
    if not xformPath: return

    # Attach the handle box to the sphere,
    # the trackball to the cube
    # or the transformBox to the wrapperKit
    if selectionPath.getTail().isOfType(SoSphere.getClassTypeId()):
        handleBoxPath = xformPath
        myHandleBox.replaceNode(xformPath)
    elif selectionPath.getTail().isOfType(SoCube.getClassTypeId()):
        trackballPath = xformPath
        myTrackball.replaceNode(xformPath)
    elif selectionPath.getTail().isOfType(SoWrapperKit.getClassTypeId()):
        transformBoxPath = xformPath
        myTransformBox.replaceNode(xformPath)

# This routine is called whenever an object gets
# deselected. It detaches the manipulator from
# the transform node, and removes it from the 
# scene graph that will not be visible.
def deselectionCallback(void, # user data is not used
                        deselectionPath):
    global myHandleBox, myTrackball, myTransformBox, handleBoxPath
    global trackballPath, transformBoxPath
    
    if deselectionPath.getTail().isOfType(SoSphere.getClassTypeId()):
        myHandleBox.replaceManip(handleBoxPath,None)
    elif deselectionPath.getTail().isOfType(SoCube.getClassTypeId()):
        myTrackball.replaceManip(trackballPath,None)
    elif deselectionPath.getTail().isOfType(SoWrapperKit.getClassTypeId()):
        myTransformBox.replaceManip(transformBoxPath,None)

# This is called when a manipulator is
# about to begin manipulation.
def dragStartCallback(myMaterial, # user data
                      dragger):   # callback data not used
    myMaterial.diffuseColor = (1,.2,.2)

# This is called when a manipulator is
# done manipulating.
def dragFinishCallback(myMaterial, # user data
                       dragger):   # callback data not used
    myMaterial.diffuseColor = (.8,.8,.8)

def main():
    global myHandleBox, myTrackball, myTransformBox
    
    # Initialize Inventor and Qt
    myWindow = SoGui.init(sys.argv[0])  
    if myWindow == None: sys.exit(1)     

    # create and set up the selection node
    selectionRoot = SoSelection()
    selectionRoot.addSelectionCallback(selectionCallback, None)
    selectionRoot.addDeselectionCallback(deselectionCallback, None)

    # create the scene graph
    root = SoSeparator()
    selectionRoot.addChild(root)

    # Read a file into contents of SoWrapperKit 
    # Translate it to the right.
    myWrapperKit = SoWrapperKit()
    root.addChild(myWrapperKit)
    myInput = SoInput()
    if not myInput.openFile("luxo.iv"):
        sys.exit(1)
    objectFromFile = SoDB.readAll(myInput)
    if objectFromFile == None:
        sys.exit(1)
    myWrapperKit.setPart("contents",objectFromFile)
    myWrapperKit.set("transform { translation 3 -1 0 }")
    wrapperMat = myWrapperKit.getPart("material",TRUE)
    wrapperMat.diffuseColor = (.8, .8, .8)

    # Create a cube with its own transform.
    cubeRoot  = SoSeparator()
    cubeXform = SoTransform()
    cubeXform.translation = (-4, 0, 0)
    root.addChild(cubeRoot)
    cubeRoot.addChild(cubeXform)

    cubeMat = SoMaterial()
    cubeMat.diffuseColor = (.8, .8, .8)
    cubeRoot.addChild(cubeMat)
    cubeRoot.addChild(SoCube())

    # add a sphere node without a transform
    # (one will be added when we attach the manipulator)
    sphereRoot = SoSeparator()
    sphereMat = SoMaterial()
    root.addChild(sphereRoot)
    sphereRoot.addChild(sphereMat)
    sphereRoot.addChild(SoSphere())
    sphereMat.diffuseColor = (.8, .8, .8)

    # create the manipulators
    myHandleBox = SoHandleBoxManip()
    myTrackball = SoTrackballManip()
    myTransformBox = SoTransformBoxManip()

    # Get the draggers and add callbacks to them. Note
    # that you don't put callbacks on manipulators. You put
    # them on the draggers which handle events for them. 
    myDragger = myTrackball.getDragger()
    myDragger.addStartCallback(dragStartCallback,cubeMat)
    myDragger.addFinishCallback(dragFinishCallback,cubeMat)

    myDragger = myHandleBox.getDragger()
    myDragger.addStartCallback(dragStartCallback,sphereMat)
    myDragger.addFinishCallback(dragFinishCallback,sphereMat)

    myDragger = myTransformBox.getDragger()
    myDragger.addStartCallback(dragStartCallback,wrapperMat)
    myDragger.addFinishCallback(dragFinishCallback,wrapperMat)

    myViewer = SoGuiExaminerViewer(myWindow)
    myViewer.setSceneGraph(selectionRoot)
    myViewer.setTitle("Attaching Manipulators")
    myViewer.show()
    myViewer.viewAll()
    
    SoGui.show(myWindow)
    SoGui.mainLoop()

if __name__ == "__main__":
    main()



from __future__ import print_function
# make the handler of the color field to call chicken_mcnuggets()
# instead of the default set handle_color() function
handler_registry['color'] = 'chicken_mcnuggets'

def chicken_mcnuggets():
  # print color.getValue().getValue()
  pass

# Initialize the color Packer (required of any property node that
# uses an SoColorPacker to set diffuse color or transparency:
colorPacker = SoColorPacker()
transpValue = floatp()

def doAction(action):
    global transpValue

    if not brightness.isIgnored() and not SoOverrideElement.getEmissiveColorOverride(action.getState()):
        emissiveColor = color.getValue() * brightness.getValue()
        # print 'doAction():', color.getValue().getValue()

        # Use the Lazy element to set emissive color. 
        # Note that this will not actually send the color to GL.       
        SoLazyElement.setEmissive(action.getState(), emissiveColor)

    # To send transparency we again check ignore flag and override element.
    if not transparency.isIgnored() and not SoOverrideElement.getTransparencyOverride(action.getState()):
        # keep a copy of the transparency that we are putting in the state:
        transpValue.assign(transparency.getValue())
     
        # The color packer must be provided when the transparency is set,
        # so that the transparency will be merged with current diffuse color
        # in the state:
        SoLazyElement.setTransparency(action.getState(), self, 1, transpValue, colorPacker)

def GLRender(action):
    action.setTransparencyType(SoGLRenderAction.SORTED_OBJECT_BLEND)
    doAction(action)

def callback(action):
    doAction(action)

wa = SoWriteAction()
wa.apply(self)

print(handler_registry)

print('== Glow script loaded ==')



#!/usr/bin/env python

###
# Copyright (c) 2002-2007 Systems in Motion
#
# Permission to use, copy, modify, and distribute this software for any
# purpose with or without fee is hereby granted, provided that the above
# copyright notice and this permission notice appear in all copies.
#
# THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
# WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
# MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
# ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
# WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
# ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
# OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
#

###
#  This is an example from The Inventor Mentor
#  chapter 10, example 2.
#
#  This demonstrates using SoGuiRenderArea::setEventCallback().
#  which causes events to be sent directly to the application
#  without being sent into the scene graph.
#  
# Clicking the left mouse button and dragging will draw 
#       points in the xy plane beneath the mouse cursor.
# Clicking middle mouse and holding causes the point set 
#       to rotate about the Y axis. 
# Clicking right mouse clears all points drawn so far out 
#       of the point set.
#

from __future__ import print_function
import sys

from pivy.coin import *
from pivy.gui.soqt import *

# PySide module has to be imported as last one if used in the same namespace
from PySide2.QtCore import *
from PySide2.QtGui import *

# Timer sensor 
# Rotate 90 degrees every second, update 30 times a second
myTicker = None
UPDATE_RATE    = 1.0/30.0
ROTATION_ANGLE = M_PI/60.0

def myProjectPoint(myRenderArea, mousex, mousey, use_coin=False):
    # Take the x,y position of mouse, and normalize to [0,1].
    # X windows have 0,0 at the upper left,
    # Inventor expects 0,0 to be the lower left.

    size = myRenderArea.getSize()
    if not use_coin:
        mousey = size[1] - mousey

    ratio = float(size[0]) / size[1] - 1
    ratiox = (ratio > 0) * ratio
    ratioy = (ratio < 0) * ratio
    x = (float(mousex) + (float(mousex) - 0.5 * float(size[0])) * ratiox) / size[0]
    y = (float(mousey) + (float(mousey) - 0.5 * float(size[1])) * ratioy) / size[1]
   
    # Get the camera and view volume
    root = myRenderArea.getSceneGraph()
    myCamera = root.getChild(0)
    myViewVolume = myCamera.getViewVolume()
   
    # Project the mouse point to a line
    p0, p1 = myViewVolume.projectPointToLine(SbVec2f(x,y))

    # Midpoint of the line intersects a plane thru the origin
    intersection = (p0 + p1) * 0.5

    return intersection

def myAddPoint(myRenderArea, point):
    root = myRenderArea.getSceneGraph()
    coord = root.getChild(2)
    myPointSet = root.getChild(3)
   
    coord.point.set1Value(coord.point.getNum(), point)
    myPointSet.numPoints = coord.point.getNum()

def myClearPoints(myRenderArea):
    root = myRenderArea.getSceneGraph()
    coord = root.getChild(2)
    myPointSet = root.getChild(3)
   
    # Delete all values starting from 0
    coord.point.deleteValues(0) 
    myPointSet.numPoints = 0

def tickerCallback(myCamera, sensor):
    mtx = SbMatrix()

    # Adjust the position
    pos = myCamera.position.getValue()
    rot = SbRotation(SbVec3f(0,1,0), ROTATION_ANGLE)
    mtx.setRotate(rot)
    pos = mtx.multVecMatrix(pos)
    myCamera.position = pos

    # Adjust the orientation
    myCamera.orientation.setValue(myCamera.orientation.getValue() * rot)
    
###############################################################
# CODE FOR The Inventor Mentor STARTS HERE  (part 1)

def myAppEventHandler(myRenderArea, anyevent):
    handled = TRUE

    if anyevent.type() == QEvent.MouseButtonPress:
        if anyevent.button() == QMouseEvent.LeftButton:
            vec = myProjectPoint(myRenderArea, anyevent.x(), anyevent.y())
            myAddPoint(myRenderArea, vec)
        elif anyevent.button() == QMouseEvent.MidButton:
            myTicker.schedule()  # start spinning the camera
        elif anyevent.button() == QMouseEvent.RightButton:
            myClearPoints(myRenderArea)  # clear the point set

    elif anyevent.type() == QEvent.MouseButtonRelease:
        if anyevent.button() == QMouseEvent.MidButton:
            myTicker.unschedule()  # stop spinning the camera

    elif anyevent.type() == QEvent.MouseMove:
        if anyevent.state() == QMouseEvent.LeftButton:
            vec = myProjectPoint(myRenderArea, anyevent.x(), anyevent.y())
            myAddPoint(myRenderArea, vec)

    else:
        handled = FALSE

    return handled

def myAppEventHandlerQt4(myRenderArea, anyevent):
    handled = TRUE

    if anyevent.type() == QEvent.MouseButtonPress:
        if anyevent.button() == Qt.LeftButton:
            vec = myProjectPoint(myRenderArea, anyevent.x(), anyevent.y())
            myAddPoint(myRenderArea, vec)
        elif anyevent.button() == Qt.MidButton:
            myTicker.schedule()  # start spinning the camera
        elif anyevent.button() == Qt.RightButton:
            myClearPoints(myRenderArea)  # clear the point set

    elif anyevent.type() == QEvent.MouseButtonRelease:
        if anyevent.button() == Qt.MidButton:
            myTicker.unschedule()  # stop spinning the camera

    elif anyevent.type() == QEvent.MouseMove:
        if anyevent.buttons() == Qt.LeftButton:
            vec = myProjectPoint(myRenderArea, anyevent.x(), anyevent.y())
            myAddPoint(myRenderArea, vec)

    else:
        handled = FALSE

    return handled


# CODE FOR The Inventor Mentor ENDS HERE
###############################################################


###############################################################
# CALLBACK WORKAROUND STARTS HERE

DRAW = FALSE
def myAppEventHandlerCoin(myRenderArea, anyevent):
    global DRAW
    handled = TRUE
    event = anyevent.getEvent()
    myRenderArea.draw = False
    if isinstance(event, SoMouseButtonEvent):
        if (event.getState() == SoMouseButtonEvent.DOWN):
            if event.getButton() == event.BUTTON1:
                pos = event.getPosition()
                vec = myProjectPoint(myRenderArea, pos[0], pos[1], use_coin=True)
                myAddPoint(myRenderArea, vec)
                DRAW=TRUE
            elif event.getButton() == event.BUTTON3:
                myTicker.schedule()  # start spinning the camera
            elif event.getButton() == event.BUTTON2:
                myClearPoints(myRenderArea)  # clear the point set

        elif (event.getState() == SoMouseButtonEvent.UP):
            if event.getButton() == event.BUTTON1:
                DRAW = False
            if event.getButton() == event.BUTTON3:
                myTicker.unschedule()  # stop spinning the camera

    elif isinstance(event, SoLocation2Event):
        if DRAW:
            pos = event.getPosition()
            vec = myProjectPoint(myRenderArea, pos[0], pos[1], use_coin=True)
            myAddPoint(myRenderArea, vec)

    else:
        handled = FALSE

    return handled

# CALLBACK WORKAROUND ENDS HERE 
###############################################################

def main():
    global myTicker
    
    # Print out usage instructions
    print("Mouse buttons:")
    print("\tLeft (with mouse motion): adds points")
    print("\tMiddle: rotates points about the Y axis")
    print("\tRight: deletes all the points")

    # Initialize Inventor and Qt
    appWindow = SoQt.init(sys.argv[0])
    if appWindow == None:
        sys.exit(1)

    # Create and set up the root node
    root = SoSeparator()

    # Add a camera
    myCamera = SoPerspectiveCamera()
    root.addChild(myCamera)                 # child 0
   
    # Use the base color light model so we don't need to 
    # specify normals
    myLightModel = SoLightModel()
    myLightModel.model = SoLightModel.BASE_COLOR
    root.addChild(myLightModel)             # child 1
   
    # Set up the camera view volume
    myCamera.position = (0, 0, 4)
    myCamera.nearDistance = 1.0
    myCamera.farDistance = 7.0
    myCamera.heightAngle = M_PI/3.0
   
    # Add a coordinate and point set
    myCoord = SoCoordinate3()
    myPointSet = SoPointSet()
    root.addChild(myCoord)                  # child 2
    root.addChild(myPointSet)               # child 3

    # Timer sensor to tick off time while middle mouse is down
    myTicker = SoTimerSensor(tickerCallback, myCamera)
    myTicker.setInterval(UPDATE_RATE)

    # Create a render area for viewing the scene
    myRenderArea = SoQtRenderArea(appWindow)
    myRenderArea.setSceneGraph(root)
    myRenderArea.setTitle("My Event Handler")


###############################################################
# as a workaround use a SoEventCallback:
    if len(sys.argv) > 1 and sys.argv[1] == "coin":
        myEventCallback = SoEventCallback()
        root.addChild(myEventCallback)
        myEventCallback.addEventCallback(SoEvent.getClassTypeId(), myAppEventHandlerCoin, myRenderArea)
# end of workaround
###############################################################

###############################################################
# TODO: this does not work with pyside
# it will run once * is solved:
# https://bugreports.qt.io/browse/PYSIDE-31?jql=project%20%3D%20PYSIDE%20AND%20resolution%20%3D%20Unresolved%20ORDER%20BY%20assignee%20ASC%2C%20priority%20DESC
# 
# CODE FOR The Inventor Mentor STARTS HERE  (part 2)
#
#    # Have render area send events to us instead of the scene 
#    # graph.  We pass the render area as user data.
    else:
        if (SoQt.getVersionToolkitString().startswith('4') or
            SoQt.getVersionToolkitString().startswith('5')):
           myRenderArea.setEventCallback(myAppEventHandlerQt4, myRenderArea)
        else:
           myRenderArea.setEventCallback(myAppEventHandler, myRenderArea)
#
# CODE FOR The Inventor Mentor ENDS HERE
###############################################################

    # Show our application window, and loop forever...
    myRenderArea.show()
    SoQt.show(appWindow)
    SoQt.mainLoop()

if __name__ == "__main__":
    main()



#!/usr/bin/env python

###
# Copyright (c) 2002-2007 Systems in Motion
#
# Permission to use, copy, modify, and distribute this software for any
# purpose with or without fee is hereby granted, provided that the above
# copyright notice and this permission notice appear in all copies.
#
# THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
# WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
# MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
# ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
# WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
# ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
# OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
#

###
# This is an example from the Inventor Mentor
# chapter 13, example 9.
#
# Blinker node.
# Use a blinker node to flash a neon ad sign on and off
#

import sys

from pivy.coin import *
from pivy.sogui import *

def main():
    # Initialize Inventor and Qt
    myWindow = SoGui.init(sys.argv[0])  
    if myWindow == None: sys.exit(1)     

    # Set up camera and light
    root = SoSeparator()
    myCamera = SoPerspectiveCamera()
    root.addChild(myCamera)
    root.addChild(SoDirectionalLight())

    # Read in the parts of the sign from a file
    myInput = SoInput()
    if not myInput.openFile("eatAtJosies.iv"):
        sys.exit(1)
    fileContents = SoDB.readAll(myInput)
    if fileContents == None:
        sys.exit(1)

    eatAt = SoNode.getByName("EatAt")
    josie = SoNode.getByName("Josies")
    frame = SoNode.getByName("Frame")

#############################################################
# CODE FOR The Inventor Mentor STARTS HERE

    # Add the non-blinking part of the sign to the root
    root.addChild(eatAt)
   
    # Add the fast-blinking part to a blinker node
    fastBlinker = SoBlinker()
    root.addChild(fastBlinker)
    fastBlinker.speed = 2  # blinks 2 times a second
    fastBlinker.addChild(josie)

    # Add the slow-blinking part to another blinker node
    slowBlinker = SoBlinker()
    root.addChild(slowBlinker)
    slowBlinker.speed = 0.5  # 2 secs per cycle 1 on, 1 off
    slowBlinker.addChild(frame)

# CODE FOR The Inventor Mentor ENDS HERE
#############################################################

    # Set up and display render area 
    myRenderArea = SoGuiRenderArea(myWindow)
    myRegion = SbViewportRegion(myRenderArea.getSize()) 
    myCamera.viewAll(root, myRegion)

    myRenderArea.setSceneGraph(root)
    myRenderArea.setTitle("Neon")
    myRenderArea.show()
    SoGui.show(myWindow)
    SoGui.mainLoop()

if __name__ == "__main__":
    main()



#!/usr/bin/env python

###
# Copyright (c) 2002-2007 Systems in Motion
#
# Permission to use, copy, modify, and distribute this software for any
# purpose with or without fee is hereby granted, provided that the above
# copyright notice and this permission notice appear in all copies.
#
# THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
# WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
# MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
# ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
# WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
# ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
# OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
#

###
# This is an example from the Inventor Mentor,
# chapter 8, example 1.
#
# This example creates and displays a B-Spline curve.
# The curve is order 3 with 7 control points and a knot
# vector of length 10.  One of its knots has multiplicity
# 2 to illustrate a curve with a spike in it.
#

import sys

from pivy.coin import *
from pivy.sogui import *

floorData = """#Inventor V2.0 ascii
Separator {
   SpotLight {
      cutOffAngle 0.9
      dropOffRate 0.2 
      location 6 12 2 
      direction 0 -1 0
   }
   ShapeHints {
      faceType UNKNOWN_FACE_TYPE
   }
   Texture2Transform {
      #rotation 1.57
      scaleFactor 8 8
   }
   Texture2 {
      filename oak.rgb
   }
   NormalBinding {
        value  PER_PART
   }
   Material { diffuseColor 1 1 1 specularColor 1 1 1 shininess 0.4 }
   DEF FloorPanel Separator {
      DEF FloorStrip Separator {
         DEF FloorBoard Separator {
            Normal { vector 0 1 0 }
            TextureCoordinate2 {
               point [ 0 0, 0.5 0, 0.5 2, 0.5 4, 0.5 6,
                       0.5 8, 0 8, 0 6, 0 4, 0 2 ] }
            Coordinate3 {
               point [ 0 0 0, .5 0 0, .5 0 -2, .5 0 -4, .5 0 -6,
                       .5 0 -8, 0 0 -8, 0 0 -6, 0 0 -4, 0 0 -2, ]
            }
            FaceSet { numVertices 10 }
            BaseColor { rgb 0.3 0.1 0.0 }
            Translation { translation 0.125 0 -0.333 }
            Cylinder { parts TOP radius 0.04167 height 0.002 }
            Translation { translation 0.25 0 0 }
            Cylinder { parts TOP radius 0.04167 height 0.002 }
            Translation { translation 0 0 -7.333 }
            Cylinder { parts TOP radius 0.04167 height 0.002 }
            Translation { translation -0.25 0 0 }
            Cylinder { parts TOP radius 0.04167 height 0.002 }
         }
         Translation { translation 0 0 8.03 }
         USE FloorBoard
         Translation { translation 0 0 8.04 }
         USE FloorBoard
      }
      Translation { translation 0.53 0 -0.87 }
      USE FloorStrip
      Translation { translation 0.53 0 -2.3 }
      USE FloorStrip
      Translation { translation 0.53 0 1.3 }
      USE FloorStrip
      Translation { translation 0.53 0 1.1 }
      USE FloorStrip
      Translation { translation 0.53 0 -0.87 }
      USE FloorStrip
      Translation { translation 0.53 0 1.7 }
      USE FloorStrip
      Translation { translation 0.53 0 -0.5 }
      USE FloorStrip
   }
   Translation { translation 4.24 0 0 }
   USE FloorPanel
   Translation { translation 4.24 0 0 }
   USE FloorPanel
}"""

##############################################################
# CODE FOR The Inventor Mentor STARTS HERE

# The control points for this curve
pts = (
   ( 4.0, -6.0,  6.0),
   (-4.0,  1.0,  0.0),
   (-1.5,  5.0, -6.0),
   ( 0.0,  2.0, -2.0),
   ( 1.5,  5.0, -6.0),
   ( 4.0,  1.0,  0.0),
   (-4.0, -6.0,  6.0))

# The knot vector
knots = (1, 2, 3, 4, 5, 5, 6, 7, 8, 9)

# Create the nodes needed for the B-Spline curve.
def makeCurve():
    curveSep = SoSeparator()
    
    # Set the draw style of the curve.
    drawStyle = SoDrawStyle()
    drawStyle.lineWidth = 4
    curveSep.addChild(drawStyle)
    
    # Define the NURBS curve including the control points
    # and a complexity.
    complexity = SoComplexity()
    controlPts = SoCoordinate3()
    curve      = SoNurbsCurve()
    complexity.value = 0.8
    controlPts.point.setValues(0, 7, pts)
    curve.numControlPoints = 7
    curve.knotVector.setValues(0, 10, knots)
    curveSep.addChild(complexity)
    curveSep.addChild(controlPts)
    curveSep.addChild(curve)
    
    return curveSep

# CODE FOR The Inventor Mentor ENDS HERE
##############################################################

def main():   
    # Initialize Inventor and Qt
    appWindow = SoGui.init(sys.argv[0])
    if appWindow == None:
        sys.exit(1)
        
    root = SoSeparator()
    
    # Create the scene graph for the heart
    heart    = SoSeparator()
    curveSep = makeCurve()
    lmodel   = SoLightModel()
    clr      = SoBaseColor()
    
    lmodel.model = SoLightModel.BASE_COLOR
    clr.rgb = (1.0, 0.0, 0.1)
    heart.addChild(lmodel)
    heart.addChild(clr)
    heart.addChild(curveSep)
    root.addChild(heart)
    
    # Create the scene graph for the floor
    floor = SoSeparator()
    xlate = SoTranslation()
    rot   = SoRotation()
    scale = SoScale()
    input = SoInput()
    
    input.setBuffer(floorData)
    result = SoDB.readAll(input)
    xlate.translation = (-12.0, -5.0, -5.0)
    scale.scaleFactor = (2.0, 1.0, 2.0)
    rot.rotation.setValue(SbRotation(SbVec3f(0.0, 1.0, 0.0), M_PI/2.0))
    floor.addChild(rot)
    floor.addChild(xlate)
    floor.addChild(scale)
    floor.addChild(result)
    root.addChild(floor)
    
    # Create the scene graph for the heart's shadow
    shadow = SoSeparator()
    shmdl  = SoLightModel()
    shmtl  = SoMaterial()
    shclr  = SoBaseColor()
    shxl   = SoTranslation()
    shscl  = SoScale()
    
    shmdl.model = SoLightModel.BASE_COLOR
    shclr.rgb = (0.21, 0.15, 0.09)
    shmtl.transparency = 0.5
    shxl.translation = (0.0, -4.9, 0.0)
    shscl.scaleFactor = (1.0, 0.0, 1.0)
    shadow.addChild(shmtl)
    shadow.addChild(shmdl)
    shadow.addChild(shclr)
    shadow.addChild(shxl)
    shadow.addChild(shscl)
    shadow.addChild(curveSep)
    root.addChild(shadow)
    
    # Initialize an Examiner Viewer
    viewer = SoGuiExaminerViewer(appWindow)
    viewer.setSceneGraph(root)
    viewer.setTitle("B-Spline Curve")
    cam = viewer.getCamera()
    cam.position = (-6.0, 8.0, 20.0)
    cam.pointAt(SbVec3f(0.0, -2.0, -4.0))
    viewer.show()
    
    SoGui.show(appWindow)
    SoGui.mainLoop()

if __name__ == "__main__":
    main()



#!/usr/bin/env python

###
# Copyright (c) 2002-2007 Systems in Motion
#
# Permission to use, copy, modify, and distribute this software for any
# purpose with or without fee is hereby granted, provided that the above
# copyright notice and this permission notice appear in all copies.
#
# THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
# WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
# MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
# ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
# WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
# ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
# OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
#

###
# This is an example from the Inventor Mentor,
# chapter 2, example 4.
#
# Use the Examiner Viewer to look at a red cone
#

import sys

from pivy.coin import *
from pivy.sogui import *

def main():
    myWindow = SoGui.init(sys.argv[0])
    if myWindow == None: sys.exit(1)

    root = SoSeparator()
    myMaterial = SoMaterial()
    myMaterial.diffuseColor = (1.0, 0.0, 0.0)
    root.addChild(myMaterial)
    root.addChild(SoCone())

    # Set up viewer:
    myViewer = SoGuiExaminerViewer(myWindow)
    myViewer.setSceneGraph(root)
    myViewer.setTitle("Examiner Viewer")
    myViewer.show()

    SoGui.show(myWindow)
    SoGui.mainLoop()

if __name__ == "__main__":
    main()



#!/usr/bin/env python

###
# Copyright (c) 2002-2007 Systems in Motion
#
# Permission to use, copy, modify, and distribute this software for any
# purpose with or without fee is hereby granted, provided that the above
# copyright notice and this permission notice appear in all copies.
#
# THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
# WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
# MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
# ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
# WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
# ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
# OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
#

###
# This is an example from the Inventor Mentor.
# chapter 15, example 4.
#
# Same as chapter 15, example 2, with one difference:
# The draggers are customized to use different geometry.
# We create our own scene graphs for the parts "translator"
# and "translatorActive."
# Then we call setPart() to replace these two parts with our 
# new scene graphs. (Remember, draggers are derived from 
# nodekits, so it's easy to change the parts).
#

import sys

from pivy.coin import *
from pivy.sogui import *

def main():
    # Initialize Inventor and Qt
    myWindow = SoGui.init(sys.argv[0])  
    if myWindow == None: sys.exit(1)     

    root = SoSeparator()

    # Create 3 translate1Draggers and place them in space.
    xDragSep = SoSeparator()
    yDragSep = SoSeparator()
    zDragSep = SoSeparator()
    root.addChild(xDragSep)
    root.addChild(yDragSep)
    root.addChild(zDragSep)
    # Separators will each hold a different transform
    xDragXf = SoTransform()
    yDragXf = SoTransform()
    zDragXf = SoTransform()
    xDragXf.set("translation  0 -4 8")
    yDragXf.set("translation -8  0 8 rotation 0 0 1  1.57")
    zDragXf.set("translation -8 -4 0 rotation 0 1 0 -1.57")
    xDragSep.addChild(xDragXf)
    yDragSep.addChild(yDragXf)
    zDragSep.addChild(zDragXf)

    # Add the draggers under the separators, after transforms
    xDragger = SoTranslate1Dragger()
    yDragger = SoTranslate1Dragger()
    zDragger = SoTranslate1Dragger()
    xDragSep.addChild(xDragger)
    yDragSep.addChild(yDragger)
    zDragSep.addChild(zDragger)

#############################################################
# CODE FOR The Inventor Mentor STARTS HERE

    # Create myTranslator and myTranslatorActive.
    # These are custom geometry for the draggers.
    myTranslator = SoSeparator()
    myTranslatorActive = SoSeparator()
    # Materials for the dragger in regular and active states
    myMtl = SoMaterial()
    myActiveMtl = SoMaterial()
    myMtl.diffuseColor = (1,1,1)
    myActiveMtl.diffuseColor = (1,1,0)
    myTranslator.addChild(myMtl)
    myTranslatorActive.addChild(myActiveMtl)
    # Same shape for both versions.
    myCube = SoCube()
    myCube.set("width 3 height .4 depth .4")
    myTranslator.addChild(myCube)
    myTranslatorActive.addChild(myCube)

    # Now, customize the draggers with the pieces we created.
    xDragger.setPart("translator",myTranslator)
    xDragger.setPart("translatorActive",myTranslatorActive)
    yDragger.setPart("translator",myTranslator)
    yDragger.setPart("translatorActive",myTranslatorActive)
    zDragger.setPart("translator",myTranslator)
    zDragger.setPart("translatorActive",myTranslatorActive)

# CODE FOR The Inventor Mentor ENDS HERE
#############################################################

    # Create shape kit for the 3D text
    # The text says 'Slide Cubes To Move Me'
    textKit = SoShapeKit()
    root.addChild(textKit)
    myText3 = SoText3()
    textKit.setPart("shape", myText3)
    myText3.justification = SoText3.CENTER
    myText3.string.set1Value(0,"Slide Cubes")
    myText3.string.set1Value(1,"To")
    myText3.string.set1Value(2,"Move Me")
    textKit.set("font { size 2}")
    textKit.set("material { diffuseColor 1 1 0}")

    # Create shape kit for surrounding box.
    # It's an unpickable cube, sized as (16,8,16)
    boxKit = SoShapeKit()
    root.addChild(boxKit)
    boxKit.setPart("shape", SoCube())
    boxKit.set("drawStyle { style LINES }")
    boxKit.set("pickStyle { style UNPICKABLE }")
    boxKit.set("material { emissiveColor 1 0 1 }")
    boxKit.set("shape { width 16 height 8 depth 16 }")

    # Create the calculator to make a translation
    # for the text.  The x component of a translate1Dragger's 
    # translation field shows how far it moved in that 
    # direction. So our text's translation is:
    # (xDragTranslate[0],yDragTranslate[0],zDragTranslate[0])
    myCalc = SoCalculator()
    myCalc.A.connectFrom(xDragger.translation)
    myCalc.B.connectFrom(yDragger.translation)
    myCalc.C.connectFrom(zDragger.translation)
    myCalc.expression = "oA = vec3f(A[0],B[0],C[0])"

    # Connect the the translation in textKit from myCalc
    textXf = textKit.getPart("transform",TRUE)
    textXf.translation.connectFrom(myCalc.oA)

    myViewer = SoGuiExaminerViewer(myWindow)
    myViewer.setSceneGraph(root)
    myViewer.setTitle("Customized Sliders")
    myViewer.viewAll()
    myViewer.show()

    SoGui.show(myWindow)
    SoGui.mainLoop()

if __name__ == "__main__":
    main()



#!/usr/bin/env python

###
# Copyright (c) 2002-2007 Systems in Motion
#
# Permission to use, copy, modify, and distribute this software for any
# purpose with or without fee is hereby granted, provided that the above
# copyright notice and this permission notice appear in all copies.
#
# THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
# WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
# MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
# ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
# WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
# ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
# OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
#

###
# This is an example from the Inventor Mentor
# chapter 14, example 2.
#
# Use nodekits to create a scene with a desk into an 
# SoWrapperKit.  Then, add a material editor for the desk and 
# a light editor on the light.
# 
# The scene is organized using an SoSceneKit, which contains
# lists for grouping lights (lightList), cameras (cameraList), 
# and objects (childList) in a scene.
# 
# Once the scene is created, a material editor is attached to 
# the wrapperKit's 'material' part, and a directional light editor
# is attached to the light's 'directionalLight' part.
#

from __future__ import print_function
import sys

from pivy.coin import *
from pivy.sogui import *

def main():
    # Initialize Inventor and Qt
    myWindow = SoGui.init(sys.argv[0])  
    if myWindow == None: sys.exit(1)     

    # SCENE!
    myScene = SoSceneKit()

    # LIGHTS! Add an SoLightKit to the "lightList." The 
    # SoLightKit creates an SoDirectionalLight by default.
    myScene.setPart("lightList[0]", SoLightKit())

    # CAMERA!! Add an SoCameraKit to the "cameraList." The 
    # SoCameraKit creates an SoPerspectiveCamera by default.
    myScene.setPart("cameraList[0]", SoCameraKit())
    myScene.setCameraNumber(0)

    # Read an object from file. 
    myInput = SoInput()
    if not myInput.openFile("desk.iv"):
        sys.exit(1)
    fileContents = SoDB.readAll(myInput)
    if fileContents == None: 
        sys.exit(1)

    # OBJECT!! Create an SoWrapperKit and set its contents to
    # be what you read from file.
    myDesk =SoWrapperKit()
    myDesk.setPart("contents", fileContents)
    myScene.setPart("childList[0]", myDesk)

    # Give the desk a good starting color
    myDesk.set("material { diffuseColor .8 .3 .1 }")

    # MATERIAL EDITOR!!  Attach it to myDesk's material node.
    # Use the SO_GET_PART macro to get this part from myDesk.
    try:
        mtlEditor = SoGuiMaterialEditor()
    except:
        print("The SoGuiMaterialEditor node has not been implemented in the " + \
              "SoGui bindings of Coin!")
        sys.exit(1)
    mtl = SO_GET_PART(myDesk,"material",SoMaterial())
    mtlEditor.attach(mtl)
    mtlEditor.setTitle("Material of Desk")
    mtlEditor.show()

    # DIRECTIONAL LIGHT EDITOR!! Attach it to the 
    # SoDirectionalLight node within the SoLightKit we made.
    try:
        ltEditor = SoGuiDirectionalLightEditor()
    except:
        print("The SoGuiDirectionalLightEditor node has not been implemented in the " + \
              "SoGui bindings of Coin!")
        sys.exit(1)        
    ltPath = myScene.createPathToPart("lightList[0].light", TRUE)
    ltEditor.attach(ltPath)
    ltEditor.setTitle("Lighting of Desk")
    ltEditor.show()
   
    myRenderArea = SoGuiRenderArea(myWindow)

    # Set up Camera with ViewAll...
    # -- use the SO_GET_PART macro to get the camera node.
    # -- viewall is a method on the 'camera' part of 
    #    the cameraKit, not on the cameraKit itself.  So the part
    #    we ask for is not 'cameraList[0]' (which is of type 
    #    SoPerspectiveCameraKit), but 
    #    'cameraList[0].camera' (which is of type 
    #    SoPerspectiveCamera).
    myCamera = SO_GET_PART(myScene, "cameraList[0].camera", SoPerspectiveCamera())
    myRegion = SbViewportRegion(myRenderArea.getSize())
    myCamera.viewAll(myScene, myRegion)

    myRenderArea.setSceneGraph(myScene)
    myRenderArea.setTitle("Main Window: Desk In A Scene Kit")
    myRenderArea.show()

    SoGui.show(myWindow)
    SoGui.mainLoop()

if __name__ == "__main__":
    main()



#!/usr/bin/env python

###
# Copyright (c) 2002-2007 Systems in Motion
#
# Permission to use, copy, modify, and distribute this software for any
# purpose with or without fee is hereby granted, provided that the above
# copyright notice and this permission notice appear in all copies.
#
# THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
# WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
# MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
# ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
# WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
# ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
# OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
#

###
# This is an example from The Inventor Mentor,
# chapter 10, example 5.
#
# The scene graph has a sphere and a text 3D object. 
# A selection node is placed at the top of the scene graph. 
# When an object is selected, a selection callback is called
# to change the material color of that object.
#

import sys

from pivy.coin import *
from pivy.sogui import *

# global data
textMaterial, sphereMaterial = [None]*2
reddish = (1.0, 0.2, 0.2)  # Color when selected
white   = (0.8, 0.8, 0.8)  # Color when not selected

# This routine is called when an object gets selected. 
# We determine which object was selected, and change 
# that objects material color.
def mySelectionCB(void, selectionPath):
    if selectionPath.getTail().isOfType(SoText3.getClassTypeId()):
        textMaterial.diffuseColor.setValue(reddish)
    elif selectionPath.getTail().isOfType(SoSphere.getClassTypeId()):
        sphereMaterial.diffuseColor.setValue(reddish)

# This routine is called whenever an object gets deselected. 
# We determine which object was deselected, and reset 
# that objects material color.
def myDeselectionCB(void, deselectionPath):
    if deselectionPath.getTail().isOfType(SoText3.getClassTypeId()):
        textMaterial.diffuseColor = white
    elif deselectionPath.getTail().isOfType(SoSphere.getClassTypeId()):
        sphereMaterial.diffuseColor = white

def main():
    global textMaterial, sphereMaterial
    
    # Initialize Inventor and Qt
    myWindow = SoGui.init(sys.argv[0])
    if myWindow == None: sys.exit(1)

    # Create and set up the selection node
    selectionRoot = SoSelection()
    selectionRoot.policy = SoSelection.SINGLE
    selectionRoot.addSelectionCallback(mySelectionCB)
    selectionRoot.addDeselectionCallback(myDeselectionCB)

    # Create the scene graph
    root = SoSeparator()
    selectionRoot.addChild(root)

    myCamera = SoPerspectiveCamera()
    root.addChild(myCamera)
    root.addChild(SoDirectionalLight())

    # Add a sphere node
    sphereRoot = SoSeparator()
    sphereTransform = SoTransform()
    sphereTransform.translation = (17., 17., 0.)
    sphereTransform.scaleFactor = (8., 8., 8.)
    sphereRoot.addChild(sphereTransform)

    sphereMaterial = SoMaterial()
    sphereMaterial.diffuseColor = (.8, .8, .8)
    sphereRoot.addChild(sphereMaterial)
    sphereRoot.addChild(SoSphere())
    root.addChild(sphereRoot)

    # Add a text node
    textRoot = SoSeparator()
    textTransform = SoTransform()
    textTransform.translation = (0., -1., 0.)
    textRoot.addChild(textTransform)

    textMaterial = SoMaterial()
    textMaterial.diffuseColor = (.8, .8, .8)
    textRoot.addChild(textMaterial)
    textPickStyle = SoPickStyle()
    textPickStyle.style = SoPickStyle.BOUNDING_BOX
    textRoot.addChild(textPickStyle)
    myText = SoText3()
    myText.string = "rhubarb"
    textRoot.addChild(myText)
    root.addChild(textRoot)

    myRenderArea = SoGuiRenderArea(myWindow)
    myRenderArea.setSceneGraph(selectionRoot)
    myRenderArea.setTitle("My Selection Callback")
    myRenderArea.show()

    # Make the camera see the whole scene
    myViewport = myRenderArea.getViewportRegion()
    myCamera.viewAll(root, myViewport, 2.0)

    SoGui.show(myWindow)
    SoGui.mainLoop()

if __name__ == "__main__":
    main()



#!/usr/bin/env python

###
# Copyright (c) 2002-2007 Systems in Motion
#
# Permission to use, copy, modify, and distribute this software for any
# purpose with or without fee is hereby granted, provided that the above
# copyright notice and this permission notice appear in all copies.
#
# THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
# WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
# MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
# ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
# WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
# ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
# OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
#

###
# This is an example from The Inventor Mentor,
# chapter 10, example 7.
#
# This example demonstrates the use of the pick filter
# callback to pick through manipulators.
#
# The scene graph has several objects. Clicking the left
# mouse on an object selects it and adds a manipulator to
# it. Clicking again deselects it and removes the manipulator.
# In this case, the pick filter is needed to deselect the
# object rather than select the manipulator.
#

import sys

from pivy.coin import *
from pivy.sogui import *

# Returns path to xform left of the input path tail.
# Inserts the xform if none found. In this example,
# assume that the xform is always the node preceeding
# the selected shape.
def findXform(p):
    # Copy the input path up to tail's parent.
    returnPath = p.copy(0, p.getLength() - 1)

    # Get the parent of the selected shape
    g = p.getNodeFromTail(1)
    tailNodeIndex = p.getIndexFromTail(0)

    # Check if there is already a transform node
    if tailNodeIndex > 0:
        n = g.getChild(tailNodeIndex - 1)
        if n.isOfType(SoTransform.getClassTypeId()):
            # Append to returnPath and return it.
            returnPath.append(n)
            return returnPath

    # Otherwise, add a transform node.
    xf = SoTransform()
    g.insertChild(xf, tailNodeIndex) # right before the tail
    # Append to returnPath and return it.
    returnPath.append(xf)
    return returnPath

# Returns the manip affecting this path. In this example,
# the manip is always preceeding the selected shape.
def findManip(p):
    # Copy the input path up to tail's parent.
    returnPath = p.copy(0, p.getLength() - 1)

    # Get the index of the last node in the path.
    tailNodeIndex = p.getIndexFromTail(0)

    # Append the left sibling of the tail to the returnPath
    returnPath.append(tailNodeIndex - 1)
    return returnPath

# Add a manipulator to the transform affecting this path
# The first parameter, userData, is not used.
def selCB(void, path):
    if path.getLength() < 2: return
    
    # Find the transform affecting this object
    xfPath = findXform(path)
    
    # Replace the transform with a manipulator
    manip = SoHandleBoxManip()
    manip.replaceNode(xfPath)

# Remove the manipulator affecting this path.
# The first parameter, userData, is not used.
def deselCB(void, path):
    if path.getLength() < 2: return

    # Find the manipulator affecting this object
    manipPath = findManip(path)

    # Replace the manipulator with a transform 
    manip = manipPath.getTail()
    manip.replaceManip(manipPath, SoTransform())

##############################################################
# CODE FOR The Inventor Mentor STARTS HERE  (part 1)

def pickFilterCB(void, pick):
    filteredPath = None
    
    # See if the picked object is a manipulator. 
    # If so, change the path so it points to the object the manip
    # is attached to.
    p = pick.getPath()
    n = p.getTail()
    if n.isOfType(SoTransformManip.getClassTypeId()):
        # Manip picked! We know the manip is attached
        # to its next sibling. Set up and return that path.
        manipIndex = p.getIndex(p.getLength() - 1)
        filteredPath = p.copy(0, p.getLength() - 1)
        filteredPath.append(manipIndex + 1) # get next sibling
    else:
        filteredPath = p

    return filteredPath

# CODE FOR The Inventor Mentor ENDS HERE  
##############################################################

# Create a sample scene graph
def myText(str, i, color):
    sep  = SoSeparator()
    col  = SoBaseColor()
    xf   = SoTransform()
    text = SoText3()
   
    col.rgb = color
    xf.translation = (6.0 * i, 0.0, 0.0)
    text.string = str
    text.parts = SoText3.FRONT | SoText3.SIDES
    text.justification = SoText3.CENTER
    sep.addChild(col)
    sep.addChild(xf)
    sep.addChild(text)
   
    return sep

def buildScene():
    scene = SoSeparator()
    font  = SoFont()
   
    font.size = 10
    scene.addChild(font)
    scene.addChild(myText("O",  0, SbColor(0, 0, 1)))
    scene.addChild(myText("p",  1, SbColor(0, 1, 0)))
    scene.addChild(myText("e",  2, SbColor(0, 1, 1)))
    scene.addChild(myText("n",  3, SbColor(1, 0, 0)))
    # Open Inventor is two words!
    scene.addChild(myText("I",  5, SbColor(1, 0, 1)))
    scene.addChild(myText("n",  6, SbColor(1, 1, 0)))
    scene.addChild(myText("v",  7, SbColor(1, 1, 1)))
    scene.addChild(myText("e",  8, SbColor(0, 0, 1)))
    scene.addChild(myText("n",  9, SbColor(0, 1, 0)))
    scene.addChild(myText("t", 10, SbColor(0, 1, 1)))
    scene.addChild(myText("o", 11, SbColor(1, 0, 0)))
    scene.addChild(myText("r", 12, SbColor(1, 0, 1)))
   
    return scene

def main():
    # Initialization
    mainWindow = SoGui.init(sys.argv[0])
    
    # Create a scene graph. Use the toggle selection policy.
    sel = SoSelection()
    sel.policy = SoSelection.TOGGLE
    sel.addChild(buildScene())

    # Create a viewer
    viewer = SoGuiExaminerViewer(mainWindow)
    viewer.setSceneGraph(sel)
    viewer.setTitle("Select Through Manips")
    viewer.show()

    # Selection callbacks
    sel.addSelectionCallback(selCB)
    sel.addDeselectionCallback(deselCB)
    sel.setPickFilterCallback(pickFilterCB)
    
    SoGui.show(mainWindow)
    SoGui.mainLoop()

if __name__ == "__main__":
    main()



#!/usr/bin/env python

from random import random
from pivy.coin import *
from pivy.gui.soqt import SoQtExaminerViewer
from ui_test import Ui_MainWindow
from PySide2.QtGui import QWidget
from PySide2.QtGui import QMainWindow
from PySide2.QtGui import QButtonGroup
from PySide2.QtCore import QObject
from PySide2.QtCore import SIGNAL

class MainWindow(QMainWindow, Ui_MainWindow):
    def __init__(self, parent = None):
        QMainWindow.__init__(self, parent)
        self.setupUi(self)
        self.setupSoQt()
        self.buttonGroup = QButtonGroup(self.groupBox)
        self.buttonGroup.addButton(self.button_x, 0)
        self.buttonGroup.addButton(self.button_y, 1)
        self.buttonGroup.addButton(self.button_z, 2)
        self.connect(self.buttonGroup, SIGNAL("buttonClicked(int)"), self.change_axis)
        self.connect(self.button, SIGNAL("clicked()"), self.change_color)
        self.connect(self.checkbox, SIGNAL("clicked()"), self.rotate)

    def change_axis(self, axis):
        self.rotxyz.axis = axis

    def change_color(self):
        self.material.diffuseColor = (random(), random(), random())

    def rotate(self):
        self.gate.enable = not self.gate.enable.getValue()

    def setupSoQt(self):
        root = SoSeparator()
        self.rotxyz = SoRotationXYZ()
        self.gate = SoGate(SoMFFloat.getClassTypeId())
        self.elapsedTime = SoElapsedTime()
        self.gate.enable = False
        self.gate.input.connectFrom(self.elapsedTime.timeOut)
        self.rotxyz.angle.connectFrom(self.gate.output)        
        self.material = SoMaterial()
        self.material.diffuseColor = (0.0, 1.0, 1.0)
        self.cone = SoCone()
        root.addChild(self.rotxyz)
        root.addChild(self.material)
        root.addChild(self.cone)

        self.exam = SoQtExaminerViewer(self.examiner)
        self.exam.setSceneGraph(root)
        #self.exam.show()



from __future__ import print_function
import os

examples = set()
for f in os.listdir(os.path.dirname(os.path.abspath(__file__))):
    name, ext = os.path.splitext(f)
    if ext == ".py" and (name != "run_all"):
        examples.add(f)

examples = sorted(examples)

print(examples)

for example in examples:
    os.system("python " + example)



#!/usr/bin/env python

###
# Copyright (c) 2002-2007 Systems in Motion
#
# Permission to use, copy, modify, and distribute this software for any
# purpose with or without fee is hereby granted, provided that the above
# copyright notice and this permission notice appear in all copies.
#
# THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
# WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
# MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
# ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
# WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
# ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
# OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
#

###
# This is an example from the Inventor Mentor,
# chapter 5, example 1.
#
# This example builds an obelisk using the Face Set node.
#

import sys

from pivy.coin import *
from pivy.sogui import *

##############################################################
## CODE FOR The Inventor Mentor STARTS HERE

##  Eight polygons. The first four are triangles 
##  The second four are quadrilaterals for the sides.
vertices = (
   ( 0, 30, 0), (-2,27, 2), ( 2,27, 2),            #front tri
   ( 0, 30, 0), (-2,27,-2), (-2,27, 2),            #left  tri
   ( 0, 30, 0), ( 2,27,-2), (-2,27,-2),            #rear  tri
   ( 0, 30, 0), ( 2,27, 2), ( 2,27,-2),            #right tri
   (-2, 27, 2), (-4,0, 4), ( 4,0, 4), ( 2,27, 2),  #front quad
   (-2, 27,-2), (-4,0,-4), (-4,0, 4), (-2,27, 2),  #left  quad
   ( 2, 27,-2), ( 4,0,-4), (-4,0,-4), (-2,27,-2),  #rear  quad
   ( 2, 27, 2), ( 4,0, 4), ( 4,0,-4), ( 2,27,-2)   #right quad
)

# Number of vertices in each polygon:
numvertices = (3, 3, 3, 3, 4, 4, 4, 4)

# Normals for each polygon:
norms = ( 
   (0, .555,  .832), (-.832, .555, 0), #front, left tris
   (0, .555, -.832), ( .832, .555, 0), #rear, right tris
   
   (0, .0739,  .9973), (-.9972, .0739, 0),#front, left quads
   (0, .0739, -.9973), ( .9972, .0739, 0),#rear, right quads
)

# set this variable to 0 if you want to use the other method
IV_STRICT = 1

def makeObeliskFaceSet():
   obelisk = SoSeparator()

   if IV_STRICT:
       # This is the preferred code for Inventor 2.1
 
       # Using the new SoVertexProperty node is more efficient
       myVertexProperty = SoVertexProperty()

       # Define the normals used:
       myVertexProperty.normal.setValues(0, 8, norms)
       myVertexProperty.normalBinding = SoNormalBinding.PER_FACE

       # Define material for obelisk
       myVertexProperty.orderedRGBA = SbColor(.4,.4,.4).getPackedValue()

       # Define coordinates for vertices
       myVertexProperty.vertex.setValues(0, 28, vertices)

       # Define the FaceSet
       myFaceSet = SoFaceSet()
       myFaceSet.numVertices.setValues(0, 8, numvertices)
 
       myFaceSet.vertexProperty = myVertexProperty
       obelisk.addChild(myFaceSet)

   else:
       # Define the normals used:
       myNormals = SoNormal()
       myNormals.vector.setValues(0, 8, norms)
       obelisk.addChild(myNormals)
       myNormalBinding = SoNormalBinding()
       myNormalBinding.value = SoNormalBinding.PER_FACE
       obelisk.addChild(myNormalBinding)

       # Define material for obelisk
       myMaterial = SoMaterial()
       myMaterial.diffuseColor = (.4, .4, .4)
       obelisk.addChild(myMaterial)

       # Define coordinates for vertices
       myCoords = SoCoordinate3()
       myCoords.point.setValues(0, 28, vertices)
       obelisk.addChild(myCoords)

       # Define the FaceSet
       myFaceSet = SoFaceSet()
       myFaceSet.numVertices.setValues(0, 8, numvertices)
       obelisk.addChild(myFaceSet)

   return obelisk

## CODE FOR The Inventor Mentor ENDS HERE
##############################################################

def main():
    # Initialize Inventor and Qt
    myWindow = SoGui.init(sys.argv[0])
    if myWindow == None: sys.exit(1)

    root = SoSeparator()

    root.addChild(makeObeliskFaceSet())

    myViewer = SoGuiExaminerViewer(myWindow)
    myViewer.setSceneGraph(root)
    myViewer.setTitle("Face Set: Obelisk")
    myViewer.show()
    myViewer.viewAll()

    SoGui.show(myWindow)
    SoGui.mainLoop()

if __name__ == "__main__":
    main()



# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file '../test.ui'
#
# Created: Tue Feb 12 18:37:15 2008
#      by: PySide UI code generator 4.3.3
#
# WARNING! All changes made in this file will be lost!

from PySide2 import QtCore, QtGui

class Ui_MainWindow(object):
    def setupUi(self, MainWindow):
        MainWindow.setObjectName("MainWindow")
        MainWindow.resize(QtCore.QSize(QtCore.QRect(0,0,783,607).size()).expandedTo(MainWindow.minimumSizeHint()))

        self.centralWidget = QtGui.QWidget(MainWindow)
        self.centralWidget.setObjectName("centralWidget")

        self.vboxlayout = QtGui.QVBoxLayout(self.centralWidget)
        self.vboxlayout.setObjectName("vboxlayout")

        self.examiner = QtGui.QWidget(self.centralWidget)
        self.examiner.setObjectName("examiner")
        self.vboxlayout.addWidget(self.examiner)

        self.hboxlayout = QtGui.QHBoxLayout()
        self.hboxlayout.setObjectName("hboxlayout")

        self.groupBox = QtGui.QGroupBox(self.centralWidget)
        self.groupBox.setObjectName("groupBox")

        self.hboxlayout1 = QtGui.QHBoxLayout(self.groupBox)
        self.hboxlayout1.setObjectName("hboxlayout1")

        self.button_x = QtGui.QRadioButton(self.groupBox)
        self.button_x.setObjectName("button_x")
        self.hboxlayout1.addWidget(self.button_x)

        self.button_y = QtGui.QRadioButton(self.groupBox)
        self.button_y.setObjectName("button_y")
        self.hboxlayout1.addWidget(self.button_y)

        self.button_z = QtGui.QRadioButton(self.groupBox)
        self.button_z.setObjectName("button_z")
        self.hboxlayout1.addWidget(self.button_z)
        self.hboxlayout.addWidget(self.groupBox)

        self.vboxlayout1 = QtGui.QVBoxLayout()
        self.vboxlayout1.setObjectName("vboxlayout1")

        self.checkbox = QtGui.QCheckBox(self.centralWidget)
        self.checkbox.setObjectName("checkbox")
        self.vboxlayout1.addWidget(self.checkbox)

        self.button = QtGui.QPushButton(self.centralWidget)
        self.button.setObjectName("button")
        self.vboxlayout1.addWidget(self.button)
        self.hboxlayout.addLayout(self.vboxlayout1)
        self.vboxlayout.addLayout(self.hboxlayout)
        MainWindow.setCentralWidget(self.centralWidget)

        self.menubar = QtGui.QMenuBar(MainWindow)
        self.menubar.setGeometry(QtCore.QRect(0,0,783,22))
        self.menubar.setObjectName("menubar")
        MainWindow.setMenuBar(self.menubar)

        self.statusbar = QtGui.QStatusBar(MainWindow)
        self.statusbar.setObjectName("statusbar")
        MainWindow.setStatusBar(self.statusbar)

        self.toolBar = QtGui.QToolBar(MainWindow)
        self.toolBar.setObjectName("toolBar")
        MainWindow.addToolBar(QtCore.Qt.TopToolBarArea,self.toolBar)

        self.retranslateUi(MainWindow)
        QtCore.QMetaObject.connectSlotsByName(MainWindow)

    def retranslateUi(self, MainWindow):
        MainWindow.setWindowTitle(QtGui.QApplication.translate("MainWindow", "MainWindow", None, QtGui.QApplication.UnicodeUTF8))
        self.groupBox.setTitle(QtGui.QApplication.translate("MainWindow", "Choose axis", None, QtGui.QApplication.UnicodeUTF8))
        self.button_x.setText(QtGui.QApplication.translate("MainWindow", "&X", None, QtGui.QApplication.UnicodeUTF8))
        self.button_y.setText(QtGui.QApplication.translate("MainWindow", "&Y", None, QtGui.QApplication.UnicodeUTF8))
        self.button_z.setText(QtGui.QApplication.translate("MainWindow", "&Z", None, QtGui.QApplication.UnicodeUTF8))
        self.checkbox.setText(QtGui.QApplication.translate("MainWindow", "Enable &rotation", None, QtGui.QApplication.UnicodeUTF8))
        self.button.setText(QtGui.QApplication.translate("MainWindow", "&Change cone color", None, QtGui.QApplication.UnicodeUTF8))
        self.toolBar.setWindowTitle(QtGui.QApplication.translate("MainWindow", "toolBar", None, QtGui.QApplication.UnicodeUTF8))




#!/usr/bin/env python

###
# Copyright (c) 2002-2007 Systems in Motion
#
# Permission to use, copy, modify, and distribute this software for any
# purpose with or without fee is hereby granted, provided that the above
# copyright notice and this permission notice appear in all copies.
#
# THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
# WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
# MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
# ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
# WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
# ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
# OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
#

###
# This is an example from the Inventor Mentor,
# chapter 9, example 3.
#
# Search Action example.
# Read in a scene from a file.
# Search through the scene looking for a light.
# If none exists, add a directional light to the scene
# and print out the modified scene.
#

import sys

from pivy.coin import *

def main():
    # Initialize Inventor
    # SoDB.init() invoked automatically upon coin module import
    
    # Open and read input scene graph
    sceneInput = SoInput()
    if not sceneInput.openFile("bird.iv"):
        return 1

    root = SoDB.readAll(sceneInput)
    if root == None:
        return 1

##############################################################
# CODE FOR The Inventor Mentor STARTS HERE

    mySearchAction = SoSearchAction()

    # Look for first existing light derived from class SoLight
    mySearchAction.setType(SoLight.getClassTypeId())
    mySearchAction.setInterest(SoSearchAction.FIRST)
    
    mySearchAction.apply(root)
    if mySearchAction.getPath() == None: # No lights found
        # Add a default directional light to the scene
        myLight = SoDirectionalLight()
        root.insertChild(myLight, 0)

# CODE FOR The Inventor Mentor ENDS HERE
##############################################################

    myWriteAction = SoWriteAction()
    myWriteAction.apply(root)

    return 0

if __name__ == "__main__":
    sys.exit(main())



#!/usr/bin/env python

###
# Copyright (c) 2002-2007 Systems in Motion
#
# Permission to use, copy, modify, and distribute this software for any
# purpose with or without fee is hereby granted, provided that the above
# copyright notice and this permission notice appear in all copies.
#
# THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
# WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
# MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
# ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
# WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
# ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
# OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
#

###
# This is an example from The Inventor Mentor
# chapter 10, example 3.
#
# The scene graph has 4 objects which may be
# selected by picking with the left mouse button
# (use shift key to extend the selection to more
# than one object).
# 
# Hitting the up arrow key will increase the size of
# each selected object; hitting down arrow will decrease
# the size of each selected object.
#
# This also demonstrates selecting objects from a Motif
# list, and calling select/deselect functions on the
# SoSelection node to change the selection. Use the Shift
# key to extend the selection (i.e. pick more than one
# item in the motif list.)
#

from __future__ import print_function
import sys

from pivy.coin import *
from pivy.sogui import *

# Global data
motifList = None
cubeTransform, sphereTransform, coneTransform, cylTransform = None, None, None, None

###############################################################
# CODE FOR The Inventor Mentor STARTS HERE  

CUBE, SPHERE, CONE, CYL, NUM_OBJECTS = 0, 1, 2, 3, 4

objectNames= (
    "Cube",
    "Sphere",
    "Cone",
    "Cylinder"
    )

# CODE FOR The Inventor Mentor ENDS HERE
###############################################################



# Create the object list widget
def createList(display, selection):
    global motifList
    
    args = [None, None, None, None]
    
    # Create a new shell window for the list
    n = 0
    XtSetArg(args[n], XmNtitle, "Selection")
    n += 1
    shell = XtAppCreateShell("example", "Inventor",
                             topLevelShellWidgetClass, display, args, n)
    
###############################################################
# CODE FOR The Inventor Mentor STARTS HERE  (part 3)

    # Create a table of object names
    table = XmString[NUM_OBJECTS]
    for i in range(NUM_OBJECTS):
        table[i] = XmStringCreate(objectNames[i], 
                                  XmSTRING_DEFAULT_CHARSET)

    # Create the list widget
    n = 0
    XtSetArg(args[n], XmNitems, table)
    n += 1
    XtSetArg(args[n], XmNitemCount, NUM_OBJECTS)
    n += 1
    XtSetArg(args[n], XmNselectionPolicy, XmEXTENDED_SELECT)
    n += 1

    motifList = XmCreateScrolledList(shell, "funcList", args, n)
    XtAddCallback(motifList, XmNextendedSelectionCallback,
                  myListPickCB, selection)
   
# CODE FOR The Inventor Mentor ENDS HERE
###############################################################

    # Free the name table
    for i in range(NUM_OBJECTS):
        XmStringFree(table[i])
    del table

    # Manage the list and return the shell
    XtManageChild(motifList)
    
    return shell

# This callback is invoked every time the user picks
# an item in the Motif list.
def myListPickCB(Widget, selection, listData):
    mySearchAction = SoSearchAction()
    
    # Remove the selection callbacks so that we don't get
    # called back while we are updating the selection list
    selection.removeSelectionCallback(mySelectionCB, TRUE)
    selection.removeDeselectionCallback(mySelectionCB, FALSE)

###############################################################
# CODE FOR The Inventor Mentor STARTS HERE  (part 4)

    # Clear the selection node, then loop through the list
    # and reselect
    selection.deselectAll()

    # Update the SoSelection based on what is selected in
    # the motif list.  We do this by extracting the string
    # from the selected XmString, and searching for the 
    # object of that name.
    for i in range(listData.selected_item_count):
        mySearchAction.setName(SoGui.decodeString(listData.selected_items[i]))
        mySearchAction.apply(selection)
        selection.select(mySearchAction.getPath())

# CODE FOR The Inventor Mentor ENDS HERE
###############################################################

    # Add the selection callbacks again
    selection.addSelectionCallback(mySelectionCB, TRUE)
    selection.addDeselectionCallback(mySelectionCB, FALSE)


# This is called whenever an object is selected or deselected.
# if userData is TRUE, then it's a selection else deselection.
# (we set this convention up when we registered this callback).
# The function updates the Motif list to reflect the current
# selection.
def mySelectionCB(isSelection, selectionPath):
    global motifList

    args = [None]
    
    # We have to temporarily change the selection policy to
    # MULTIPLE so that we can select and deselect single items.
    XtSetArg(args[0], XmNselectionPolicy, XmMULTIPLE_SELECT)
    XtSetValues(motifList, args, 1)
    
    node = selectionPath.getTail()
    
    for i in range(NUM_OBJECTS):
       if node.getName() == objectNames[i]:
           if isSelection:
               XmListSelectPos(motifList, i+1, False)
           else: XmListDeselectPos(motifList, i+1)
           XmUpdateDisplay(motifList)
           break

    # Restore the selection policy to extended.
    XtSetArg(args[0], XmNselectionPolicy, XmEXTENDED_SELECT)
    XtSetValues(motifList, args, 1)

###############################################################
# CODE FOR The Inventor Mentor STARTS HERE  (Example 10-4)

# Scale each object in the selection list
def myScaleSelection(selection, sf):
    global cubeTransform, sphereTransform, coneTransform, cylTransform

    # Scale each object in the selection list
    for i in range(selection.getNumSelected()):
        selectedPath = selection.getPath(i)
        xform = None

        # Look for the shape node, starting from the tail of the
        # path.  Once we know the type of shape, we know which
        # transform to modify
        for j in range(selectedPath.getLength()):
            if xform != None: break
            n = selectedPath.getNodeFromTail(j)

            if n.isOfType(SoCube.getClassTypeId()):
                xform = cubeTransform
            elif n.isOfType(SoCone.getClassTypeId()):
                xform = coneTransform
            elif n.isOfType(SoSphere.getClassTypeId()):
                xform = sphereTransform
            elif n.isOfType(SoCylinder.getClassTypeId()):
                xform = cylTransform

        # Apply the scale
        scaleFactor = xform.scaleFactor.getValue()
        scaleFactor *= sf
        xform.scaleFactor = scaleFactor

# If the event is down arrow, then scale down every object 
# in the selection list if the event is up arrow, scale up.
# The userData is the selectionRoot from main().
def myKeyPressCB(selection, eventCB):
    event = eventCB.getEvent()

    # check for the Up and Down arrow keys being pressed
    if SoKeyboardEvent.isKeyPressEvent(event, SoKeyboardEvent.UP_ARROW):
        myScaleSelection(selection, 1.1)
        eventCB.setHandled()
    elif SoKeyboardEvent.isKeyPressEvent(event, SoKeyboardEvent.DOWN_ARROW):
        myScaleSelection(selection, 1.0/1.1)
        eventCB.setHandled()

# CODE FOR The Inventor Mentor ENDS HERE
###############################################################

def main():
    global cubeTransform, sphereTransform, coneTransform, cylTransform

    # Print out usage message
    print("Left mouse button        - selects object")
    print("<shift>Left mouse button - selects multiple objects")
    print("Up and Down arrows       - scale selected objects")
    
    # Initialize Inventor and Qt
    myWindow = SoGui.init(sys.argv[0])
    if myWindow == None: sys.exit(1)

    # Create and set up the selection node
    selectionRoot = SoSelection()
    selectionRoot.policy = SoSelection.SHIFT
    selectionRoot.addSelectionCallback(mySelectionCB, TRUE)
    selectionRoot.addDeselectionCallback(mySelectionCB, FALSE)
   
    # Add a camera and some light
    myCamera = SoPerspectiveCamera()
    selectionRoot.addChild(myCamera)
    selectionRoot.addChild(SoDirectionalLight())

    # Add an event callback so we can receive key press events
    myEventCB = SoEventCallback()
    myEventCB.addEventCallback(SoKeyboardEvent.getClassTypeId(), 
                               myKeyPressCB, selectionRoot)
    selectionRoot.addChild(myEventCB)

    # Add some geometry to the scene
    # a red cube
    cubeRoot = SoSeparator()
    cubeMaterial = SoMaterial()
    cubeTransform = SoTransform()
    cube = SoCube()
    cubeRoot.addChild(cubeTransform)
    cubeRoot.addChild(cubeMaterial)
    cubeRoot.addChild(cube)
    cubeTransform.translation = (-2, 2, 0)
    cubeMaterial.diffuseColor = (.8, 0, 0)
    selectionRoot.addChild(cubeRoot)

    # a blue sphere
    sphereRoot = SoSeparator()
    sphereMaterial = SoMaterial()
    sphereTransform = SoTransform()
    sphere = SoSphere()
    sphereRoot.addChild(sphereTransform)
    sphereRoot.addChild(sphereMaterial)
    sphereRoot.addChild(sphere)
    sphereTransform.translation = (2, 2, 0)
    sphereMaterial.diffuseColor = (0, 0, .8)
    selectionRoot.addChild(sphereRoot)

    # a green cone
    coneRoot = SoSeparator()
    coneMaterial = SoMaterial()
    coneTransform = SoTransform()
    cone = SoCone()
    coneRoot.addChild(coneTransform)
    coneRoot.addChild(coneMaterial)
    coneRoot.addChild(cone)
    coneTransform.translation = (2, -2, 0)
    coneMaterial.diffuseColor = (0, .8, 0)
    selectionRoot.addChild(coneRoot)

    # a magenta cylinder
    cylRoot = SoSeparator()
    cylMaterial = SoMaterial()
    cylTransform = SoTransform()
    cyl = SoCylinder()
    cylRoot.addChild(cylTransform)
    cylRoot.addChild(cylMaterial)
    cylRoot.addChild(cyl)
    cylTransform.translation = (-2, -2, 0)
    cylMaterial.diffuseColor = (.8, 0, .8)
    selectionRoot.addChild(cylRoot)

###############################################################
# CODE FOR The Inventor Mentor STARTS HERE  (part 2)

    cube.setName(objectNames[CUBE])
    sphere.setName(objectNames[SPHERE])
    cone.setName(objectNames[CONE])
    cyl.setName(objectNames[CYL])

# CODE FOR The Inventor Mentor ENDS HERE
###############################################################

    # Create a render area for viewing the scene
    myRenderArea = SoGuiRenderArea(myWindow)
    boxhra = SoBoxHighlightRenderAction()
    myRenderArea.setGLRenderAction(boxhra)
    myRenderArea.redrawOnSelectionChange(selectionRoot)
    myRenderArea.setSceneGraph(selectionRoot)
    myRenderArea.setTitle("Motif Selection List")

    # Make the camera see the whole scene
    viewportRegion = myRenderArea.getViewportRegion()
    myCamera.viewAll(selectionRoot, viewportRegion, 2.0)

    # Create a Motif list for selecting objects without picking
    objectList = createList(XtDisplay(myWindow), selectionRoot)

    # Show our application window, and loop forever...
    myRenderArea.show()
    SoGui.show(myWindow)
    SoGui.show(objectList)
    SoGui.mainLoop()

if __name__ == "__main__":
    print("This example is not functional as it is GUI toolkit dependent!")
    sys.exit(1)
    main()



#!/usr/bin/env python

###
# Copyright (c) 2002-2007 Systems in Motion
#
# Permission to use, copy, modify, and distribute this software for any
# purpose with or without fee is hereby granted, provided that the above
# copyright notice and this permission notice appear in all copies.
#
# THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
# WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
# MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
# ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
# WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
# ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
# OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
#

###
# This is an example from the Inventor Mentor.
# chapter 15, example 1.
#
# Uses an SoTranslate1Dragger to control the bottomRadius field 
# of an SoCone.  The 'translation' field of the dragger is the 
# input to an SoDecomposeVec3f engine. The engine extracts the
# x component from the translation. This extracted value is
# connected to the bottomRadius field of the cone.
#

import sys

from pivy.coin import *
from pivy.sogui import *

def main():
    # Initialize Inventor and Qt
    myWindow = SoGui.init(sys.argv[0])  
    if myWindow == None: sys.exit(1)     

    root = SoSeparator()

    # Create myDragger with an initial translation of (1,0,0)
    myDragger = SoTranslate1Dragger()
    root.addChild(myDragger)
    myDragger.translation = (1,0,0)

    # Place an SoCone above myDragger
    myTransform = SoTransform()
    myCone = SoCone()
    root.addChild(myTransform)
    root.addChild(myCone)
    myTransform.translation = (0,3,0)

    # SoDecomposeVec3f engine extracts myDragger's x-component
    # The result is connected to myCone's bottomRadius.
    myEngine = SoDecomposeVec3f()
    myEngine.vector.connectFrom(myDragger.translation)
    myCone.bottomRadius.connectFrom(myEngine.x)

    # Display them in a viewer
    myViewer = SoGuiExaminerViewer(myWindow)
    myViewer.setSceneGraph(root)
    myViewer.setTitle("Dragger Edits Cone Radius")
    myViewer.viewAll()
    myViewer.show()

    SoGui.show(myWindow)
    SoGui.mainLoop()

if __name__ == "__main__":
    main()



#!/usr/bin/env python

###
# Copyright (c) 2002-2007 Systems in Motion
#
# Permission to use, copy, modify, and distribute this software for any
# purpose with or without fee is hereby granted, provided that the above
# copyright notice and this permission notice appear in all copies.
#
# THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
# WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
# MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
# ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
# WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
# ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
# OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
#

###
# This is an example from the Inventor Mentor,
# chapter 2, example 1.
#
# Hello Cone example program; draws a red cone in a window.
#

import sys

from pivy.sogui import *
from pivy.coin import *

def main():
    # Initialize Inventor. This returns a main window to use.
    # If unsuccessful, exit.

    myWindow = SoGui.init(sys.argv[0])
    if myWindow == None: sys.exit(1)

    # Make a scene containing a red cone
    root = SoSeparator()
    myCamera = SoPerspectiveCamera()
    myMaterial = SoMaterial()
    root.addChild(myCamera)
    root.addChild(SoDirectionalLight())
    myMaterial.diffuseColor = (1.0, 0.0, 0.0)   # Red
    root.addChild(myMaterial)
    root.addChild(SoCone())

    # Create a renderArea in which to see our scene graph.
    # The render area will appear within the main window.
    myRenderArea = SoGuiRenderArea(myWindow)

    # Make myCamera see everything.
    myCamera.viewAll(root, myRenderArea.getViewportRegion())

    # Put our scene in myRenderArea, change the title
    myRenderArea.setSceneGraph(root)
    myRenderArea.setTitle("Hello Cone")
    myRenderArea.show()

    SoGui.show(myWindow)  # Display main window
    SoGui.mainLoop()    # Main Inventor event loop

if __name__ == "__main__":
    main()



#!/usr/bin/env python

###
# Copyright (c) 2002-2007 Systems in Motion
#
# Permission to use, copy, modify, and distribute this software for any
# purpose with or without fee is hereby granted, provided that the above
# copyright notice and this permission notice appear in all copies.
#
# THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
# WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
# MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
# ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
# WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
# ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
# OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
#

###
# This is an example from the Inventor Mentor,
# chapter 3, example 1.
#
# This code shows how to create a molecule out of 3 spherical
# atoms.  The molecule illustrates how the ordering of nodes
# within a scene graph affects the rendered image.
#
#

import sys

from pivy.coin import *
from pivy.sogui import *

def makeWaterMolecule():
##############################################################
#  CODE FOR The Inventor Mentor STARTS HERE

    # Construct all parts
    waterMolecule = SoGroup()  # water molecule

    oxygen = SoGroup()         # oxygen atom
    redPlastic = SoMaterial()
    sphere1 = SoSphere()
    
    hydrogen1 = SoGroup()      # hydrogen atoms
    hydrogen2 = SoGroup()
    hydrogenXform1 = SoTransform()
    hydrogenXform2 = SoTransform()
    whitePlastic = SoMaterial()
    sphere2 = SoSphere()
    sphere3 = SoSphere()
    
    # Set all field values for the oxygen atom
    redPlastic.ambientColor = (1.0, 0.0, 0.0)
    redPlastic.diffuseColor = (1.0, 0.0, 0.0) 
    redPlastic.specularColor = (0.5, 0.5, 0.5)
    redPlastic.shininess = 0.5
    
    # Set all field values for the hydrogen atoms
    hydrogenXform1.scaleFactor = (0.75, 0.75, 0.75)  
    hydrogenXform1.translation = (0.0, -1.2, 0.0)  
    hydrogenXform2.translation = (1.1852, 1.3877, 0.0)
    whitePlastic.ambientColor = (1.0, 1.0, 1.0)  
    whitePlastic.diffuseColor = (1.0, 1.0, 1.0) 
    whitePlastic.specularColor = (0.5, 0.5, 0.5)
    whitePlastic.shininess = 0.5
    
    # Create a hierarchy
    waterMolecule.addChild(oxygen)   
    waterMolecule.addChild(hydrogen1)   
    waterMolecule.addChild(hydrogen2)
    
    oxygen.addChild(redPlastic)
    oxygen.addChild(sphere1)
    hydrogen1.addChild(hydrogenXform1)
    hydrogen1.addChild(whitePlastic)
    hydrogen1.addChild(sphere2)
    hydrogen2.addChild(hydrogenXform2)
    hydrogen2.addChild(sphere3)

## CODE FOR The Inventor Mentor ENDS HERE
##############################################################

    return waterMolecule

def main():
    # Initialize Inventor and Qt
    myWindow = SoGui.init(sys.argv[0])
    if myWindow == None: sys.exit(1)

    root = SoSeparator()

    # This function contains our code fragment.
    root.addChild(makeWaterMolecule())

    myViewer = SoGuiExaminerViewer(myWindow)
    myViewer.setSceneGraph(root)
    myViewer.setTitle("H two O")
    myViewer.show()
    myViewer.viewAll()

    SoGui.show(myWindow)
    SoGui.mainLoop()

if __name__ == "__main__":
    main()



#!/usr/bin/env python

###
# Copyright (c) 2002-2007 Systems in Motion
#
# Permission to use, copy, modify, and distribute this software for any
# purpose with or without fee is hereby granted, provided that the above
# copyright notice and this permission notice appear in all copies.
#
# THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
# WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
# MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
# ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
# WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
# ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
# OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
#

###
# This is an example from the Inventor Mentor,
# chapter 9, example 2.
#
# Using the offscreen renderer to generate a texture map.
# Generate simple scene and grab the image to use as
# a texture map.
#

from __future__ import print_function
import sys

from pivy.coin import *
from pivy.sogui import *

def generateTextureMap(root, texture, textureWidth, textureHeight):
    myViewport = SbViewportRegion(textureWidth, textureHeight)

    # Render the scene
    myRenderer = SoOffscreenRenderer(myViewport)
    myRenderer.setBackgroundColor(SbColor(0.3, 0.3, 0.3))
    if not myRenderer.render(root):
        del myRenderer
        return FALSE

    # Generate the texture
    texture.image.setValue(SbVec2s(textureWidth, textureHeight),
                           SoOffscreenRenderer.RGB, myRenderer.getBuffer())

    del myRenderer
    return TRUE

def main():
    # Initialize Inventor and Qt
    appWindow = SoGui.init(sys.argv[0])
    if appWindow == None:
        sys.exit(1)

    # Make a scene from reading in a file
    texRoot = SoSeparator()
    input = SoInput()

    input.openFile("jumpyMan.iv")
    result = SoDB.readAll(input)

    myCamera = SoPerspectiveCamera()
    rot = SoRotationXYZ()
    rot.axis = SoRotationXYZ.X
    rot.angle = M_PI_2
    myCamera.position = (-0.2, -0.2, 2.0)
    myCamera.scaleHeight(0.4)
    texRoot.addChild(myCamera)
    texRoot.addChild(SoDirectionalLight())
    texRoot.addChild(rot)
    texRoot.addChild(result)

    # Generate the texture map
    texture = SoTexture2()
    if generateTextureMap(texRoot, texture, 64, 64):
        print("Successfully generated texture map")
    else:
        print("Could not generate texture map")

    # Make a scene with a cube and apply the texture to it
    root = SoSeparator()
    root.addChild(texture)
    root.addChild(SoCube())

    # Initialize an Examiner Viewer
    viewer = SoGuiExaminerViewer(appWindow)
    viewer.setSceneGraph(root)
    viewer.setTitle("Offscreen Rendered Texture")

    # In Inventor 2.1, if the machine does not have hardware texture
    # mapping, we must override the default drawStyle to display textures.
    # viewer.setDrawStyle(SoGuiViewer.STILL, SoGuiViewer.VIEW_AS_IS)

    viewer.show()

    SoGui.show(appWindow)
    SoGui.mainLoop()

if __name__ == "__main__":
    main()



#!/usr/bin/env python

###
# Copyright (c) 2002-2007 Systems in Motion
#
# Permission to use, copy, modify, and distribute this software for any
# purpose with or without fee is hereby granted, provided that the above
# copyright notice and this permission notice appear in all copies.
#
# THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
# WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
# MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
# ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
# WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
# ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
# OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
#

###
# This is an example from the Inventor Mentor,
# chapter 11, example 2.
#
# Example of creatinge a scene graph by reading from a string.
# Create a dodecahedron, made of an IndexedFaceSet.  
#

import sys

from pivy.coin import *
from pivy.sogui import *

#############################################################
# CODE FOR The Inventor Mentor STARTS HERE

# Reads a dodecahedron from the following string: 
# (Note: ANSI compilers automatically concatenate 
# adjacent string literals together, so the compiler sees 
# this as one big string)
#
# this note can be happily igonored for python programs! --tamer ;)
# use the elegant triple quote feature of python instead

dodecahedron = """Separator {
   Normal {
      vector [
         0.553341 0 0.832955, 0.832955 0.553341 0,
         0.832955 -0.553341 0, 0 -0.832955 0.553341,
         -0.553341 0 0.832955, 0 0.832955 0.553341,
         0 0.832955 -0.553341, -0.832955 0.553341 0,
         -0.832955 -0.553341 0, 0 -0.832955 -0.553341,
         0.553341 0 -0.832955, -0.553341 0 -0.832955,
      ]
   }
   NormalBinding { value PER_FACE }
   Material {
      diffuseColor [
         1  0  0,   0 1  0,   0  0 1,   0  1  1,
         1  0  1,  .5 1  0,  .5  0 1,  .5  1  1,
         1 .3 .7,  .3 1 .7,  .3 .7 1,  .5 .5 .8
      ]
   }
   MaterialBinding { value PER_FACE }
   Coordinate3 {
      point [
         1.7265 0 0.618,    1 1 1,
         0 0.618 1.7265,    0 -0.618 1.7265,
         1 -1 1,    -1 -1 1,
         -0.618 -1.7265 0,    0.618 -1.7265 0,
         1 -1 -1,    1.7265 0 -0.618,
         1 1 -1,    0.618 1.7265 0,
         -0.618 1.7265 0,    -1 1 1,
         -1.7265 0 0.618,    -1.7265 0 -0.618,
         -1 -1 -1,    0 -0.618 -1.7265,
         0 0.618 -1.7265,    -1 1 -1
      ]
   }
   IndexedFaceSet {
      coordIndex [
         1, 2, 3, 4, 0, -1,  0, 9, 10, 11, 1, -1,
         4, 7, 8, 9, 0, -1,  3, 5, 6, 7, 4, -1,
         2, 13, 14, 5, 3, -1,  1, 11, 12, 13, 2, -1,
         10, 18, 19, 12, 11, -1,  19, 15, 14, 13, 12, -1,
         15, 16, 6, 5, 14, -1,  8, 7, 6, 16, 17, -1,
         9, 8, 17, 18, 10, -1,  18, 17, 16, 15, 19, -1,
      ]
   }
}"""

# Routine to create a scene graph representing a dodecahedron
def makeDodecahedron():
    # Read from the string.
    input = SoInput()
    input.setBuffer(dodecahedron)

    result = SoDB.readAll(input)

    return result

# CODE FOR The Inventor Mentor ENDS HERE
#############################################################

def main():
    # Initialize Inventor and Qt
    myWindow = SoGui.init(sys.argv[0])
    if myWindow == None: sys.exit(1)

    root = makeDodecahedron()

    myViewer = SoGuiExaminerViewer(myWindow)
    myViewer.setSceneGraph(root)
    myViewer.setTitle("String Reader")
    myViewer.show()

    SoGui.show(myWindow)
    SoGui.mainLoop()

if __name__ == "__main__":
    main()



from __future__ import print_function
import sys
from pivy import coin
from pivy.gui import soqt
# import shiboken if you want to use the widget within qt

myWindow = soqt.SoQt.init(sys.argv[0])
print(myWindow)
scene = coin.SoSeparator()
cam = coin.SoPerspectiveCamera()
cam.position = (0, 0, 4)
light = coin.SoLightModel()
light.model = coin.SoLightModel.BASE_COLOR
scene += light, cam, coin.SoCone()
viewer = soqt.SoQtRenderArea(myWindow)
viewer.setSceneGraph(scene)
viewer.setTitle("Examiner Viewer")
viewer.show()
soqt.SoQt.show(myWindow)
soqt.SoQt.mainLoop()


###
# This file is part of a set of example programs for the Coin library.
# Copyright (C) 2000-2003 by Systems in Motion. All rights reserved.
#
#                  <URL:http://www.coin3d.org>
#
# This sourcecode can be redistributed and/or modified under the
# terms of the GNU General Public License version 2 as published by
# the Free Software Foundation. See the file COPYING at the root
# directory of the distribution for more details.
#
# As a special exception, all sourcecode of the demo examples can be
# used for any purpose for licensees of the Coin Professional
# Edition License, without the restrictions of the GNU GPL. See our
# web pages for information about how to acquire a Professional Edition
# License.
#
# Systems in Motion, <URL:http://www.sim.no>, <mailto:support@sim.no>
#

import array
from math import sin, cos

from pivy.coin import *

def generate8bitVoxelSet(dim):
    blocksize = dim[0] * dim[1] * dim[2];
    voxels = array.array('B', [0] * dim[0] * dim[1] * dim[2])
    t = 0

    for i in range(50016):
        v = (sin((t + 1.4234) * 1.9) * sin(t) * 0.45 + 0.5,
             cos((t * 2.5) - 10) * 0.45 + 0.5,
             cos((t - 0.23123) * 3) * sin(t + 0.5) * cos(t) * 0.45 + 0.5)

        # assert(v[0] < 1.0 and v[1] < 1.0 and v[2] < 1.0)
        nx = int(dim[0] * v[0])
        ny = int(dim[1] * v[1])
        nz = int(dim[2] * v[2])

        memposition = nz*dim[0]*dim[1] + ny*dim[0] + nx
        voxels[memposition] = int((255.0 * cos(t)) % 256)

        t += 0.001

    return voxels



#!/usr/bin/env python

###
# Copyright (c) 2002-2007 Systems in Motion
#
# Permission to use, copy, modify, and distribute this software for any
# purpose with or without fee is hereby granted, provided that the above
# copyright notice and this permission notice appear in all copies.
#
# THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
# WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
# MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
# ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
# WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
# ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
# OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
#


import sys

from pivy.sogui import *
from pivy import coin, utils

def main():
    myWindow = SoGui.init(sys.argv[0])
    if myWindow == None: sys.exit(1)

    # add a new marker type:
    utils.add_marker_from_svg("test.svg", "CUSTOM_MARKER",  30)

    root = coin.SoSeparator()
    color = coin.SoMaterial()
    color.diffuseColor = (1., 0., 0.)

    marker = coin.SoMarkerSet()
    marker.markerIndex = coin.SoMarkerSet.CUSTOM_MARKER
    data = coin.SoCoordinate3()
    data.point.setValue(0, 0, 0)
    data.point.setValues(0, 1, [[0., 0., 0.]])

    myCamera = coin.SoPerspectiveCamera()
    root.addChild(myCamera)
    root.addChild(coin.SoDirectionalLight())
    root.addChild(color)
    root.addChild(data)
    root.addChild(marker)
    root.addChild(data)
    root.addChild(marker)

    myRenderArea = SoGuiRenderArea(myWindow)

    myCamera.viewAll(root, myRenderArea.getViewportRegion())

    myRenderArea.setSceneGraph(root)
    myRenderArea.setTitle("Hello Cone")
    myRenderArea.show()

    SoGui.show(myWindow)
    SoGui.mainLoop()

if __name__ == "__main__":
    main()


#!/usr/bin/env python

###
# Copyright (c) 2002-2007 Systems in Motion
#
# Permission to use, copy, modify, and distribute this software for any
# purpose with or without fee is hereby granted, provided that the above
# copyright notice and this permission notice appear in all copies.
#
# THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
# WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
# MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
# ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
# WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
# ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
# OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
#

###
# This is an example from the Inventor Mentor,
# chapter 16, example 1.
#
# This example shows how to use the overlay planes with the
# viewer components. By default color 0 is used for the
# overlay planes background color (clear color), so we use
# color 1 for the object. This example also shows how to
# load the overlay color map with the wanted color.
#

from __future__ import print_function
import sys

from pivy.coin import *
from pivy.sogui import *

overlayScene = """
#Inventor V2.0 ascii

Separator {
   OrthographicCamera {
      position 0 0 5
      nearDistance 1.0
      farDistance 10.0
      height 1
   }
   LightModel { model BASE_COLOR }
   ColorIndex { index 1 }
   Coordinate3 { point [ -1 -1 0, -1 1 0, 1 1 0, 1 -1 0] }
   FaceSet {}
}"""

def main():
    # Initialize Inventor and Qt
    myWindow = SoGui.init(sys.argv[0])  
    if myWindow == None: sys.exit(1)     

    # read the scene graph in
    input = SoInput()
    input.setBuffer(overlayScene)
    scene = SoDB.readAll(input)
    if scene == None:
        print("Couldn't read scene")
        sys.exit(1)

    # Allocate the viewer, set the overlay scene and
    # load the overlay color map with the wanted color.
    color = SbColor(.5, 1, .5)
    myViewer = SoGuiExaminerViewer(myWindow)
    myViewer.setSceneGraph(SoCone())
    myViewer.setOverlaySceneGraph(scene)
    myViewer.setOverlayColorMap(1, 1, color)
    myViewer.setTitle("Overlay Plane")
   
    # Show the viewer and loop forever
    myViewer.show()
    # QtRealizeWidget(myWindow)
    SoGui.mainLoop()

if __name__ == "__main__":
    main()



#!/usr/bin/env python

###
# Copyright (c) 2002-2008 Kongsberg SIM
#
# Permission to use, copy, modify, and distribute this software for any
# purpose with or without fee is hereby granted, provided that the above
# copyright notice and this permission notice appear in all copies.
#
# THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
# WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
# MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
# ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
# WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
# ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
# OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
#

import os
import sys

from PySide2 import QtCore, QtGui
from PySide2.QtGui import QMainWindow, QWorkspace, QAction, QFileDialog, QApplication

from pivy.coin import SoInput, SoDB
from pivy.quarter import QuarterWidget


class MdiQuarterWidget(QuarterWidget):
    def __init__(self, parent, sharewidget):
        QuarterWidget.__init__(self, parent=parent, sharewidget=sharewidget)

    def loadFile(self, filename):
        in_ = SoInput()
        if (in_.openFile(str(filename.toLatin1()))):
            root = SoDB.readAll(in_)
        if (root):
            self.setSceneGraph(root)
            self.currentfile = filename
            self.setWindowTitle(filename)
            return True
        return False

    def currentFile(self):
        return self.currentfile

    def minimumSizeHint(self):
        return QtCore.QSize(640, 480)


class MdiMainWindow(QMainWindow):
    def __init__(self, qApp):
        QMainWindow.__init__(self)
        self._firstwidget = None
        self._workspace = QWorkspace()
        self.setCentralWidget(self._workspace)
        self.setAcceptDrops(True)
        self.setWindowTitle("Pivy Quarter MDI example")

        filemenu = self.menuBar().addMenu("&File")
        windowmenu = self.menuBar().addMenu("&Windows")

        fileopenaction = QAction("&Open", self)
        fileexitaction = QAction("E&xit", self)
        tileaction = QAction("Tile", self)
        cascadeaction = QAction("Cascade", self)

        filemenu.addAction(fileopenaction)
        filemenu.addAction(fileexitaction)
        windowmenu.addAction(tileaction)
        windowmenu.addAction(cascadeaction)

        self.connect(fileopenaction, QtCore.SIGNAL("triggered()"), self.open)
        self.connect(fileexitaction, QtCore.SIGNAL("triggered()"), QtGui.qApp.closeAllWindows)
        self.connect(tileaction, QtCore.SIGNAL("triggered()"), self._workspace.tile)
        self.connect(cascadeaction, QtCore.SIGNAL("triggered()"), self._workspace.cascade)

        windowmapper = QtCore.QSignalMapper(self)
        self.connect(windowmapper, QtCore.SIGNAL("mapped(QWidget *)"), self._workspace.setActiveWindow)

        self.dirname = os.curdir        

    def dragEnterEvent(self, event):
        # just accept anything...
        event.acceptProposedAction()

    def dropEvent(self, event):
        mimedata = event.mimeData()
        if mimedata.hasUrls():
            path = mimedata.urls().takeFirst().path()
            self.open_path(path)

    def closeEvent(self, event):
        self._workspace.closeAllSubWindows()

    def open(self):
        self.open_path(QFileDialog.getOpenFileName(self, "", self.dirname))

    def open_path(self, filename):
        self.dirname = os.path.dirname(str(filename.toLatin1()))
        if not filename.isEmpty():
            existing = self.findMdiChild(filename)
            if existing:
                self._workspace.setActiveWindow(existing)
                return
        child = self.createMdiChild()
        if (child.loadFile(filename)):
            self.statusBar().showMessage("File loaded", 2000)
            child.show()
        else:
            child.close()

    def findMdiChild(self, filename):
        canonicalpath = QtCore.QFileInfo(filename).canonicalFilePath()
        for window in self._workspace.windowList():
            mdiwidget = window
            if mdiwidget.currentFile() == canonicalpath:
                return mdiwidget
        return 0;

    def createMdiChild(self):
        widget = MdiQuarterWidget(None, self._firstwidget)
        self._workspace.addSubWindow(widget)
        if not self._firstwidget:
            self._firstwidget = widget
        return widget


def main():
    app = QApplication(sys.argv)

    mdi = MdiMainWindow(app)    
    mdi.show()
    if len(sys.argv)==2:
        mdi.open_path(QtCore.QString(sys.argv[1]))
    sys.exit(app.exec_())


if __name__ == '__main__':
    main()
